@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7962 $
-## |  Last changed: $Date: 2024-05-31 13:41:37 +0200 (Fr, 31 Mai 2024) $
+## |  File version: $Revision: 8670 $
+## |  Last changed: $Date: 2025-04-10 08:07:04 +0200 (Do, 10 Apr 2025) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -75,6 +75,7 @@ TrialDesign <- R6::R6Class("TrialDesign",
         stageLevels = NULL,
         alphaSpent = NULL,
         bindingFutility = NULL,
+        directionUpper = NULL,
         tolerance = NULL,
         initialize = function(...,
                 kMax = NA_integer_,
@@ -85,6 +86,7 @@ TrialDesign <- R6::R6Class("TrialDesign",
                 stageLevels = NA_real_,
                 alphaSpent = NA_real_,
                 bindingFutility = NA,
+                directionUpper = NA,
                 tolerance = 1e-06 # C_ANALYSIS_TOLERANCE_DEFAULT
                 ) {
             self$kMax <- kMax
@@ -95,6 +97,7 @@ TrialDesign <- R6::R6Class("TrialDesign",
             self$stageLevels <- stageLevels
             self$alphaSpent <- alphaSpent
             self$bindingFutility <- bindingFutility
+            self$directionUpper <- directionUpper
             self$tolerance <- tolerance
             super$initialize(...)
 
@@ -293,7 +296,26 @@ TrialDesignCharacteristics <- R6::R6Class("TrialDesignCharacteristics",
 #'
 #' @export
 #'
-print.TrialDesignCharacteristics <- function(x, ..., markdown = FALSE, showDesign = TRUE) {
+print.TrialDesignCharacteristics <- function(x, ..., markdown = NA, showDesign = TRUE) {
+    sysCalls <- sys.calls()
+
+    if (is.na(markdown)) {
+        markdown <- .isMarkdownEnabled("print")
+    }
+
+    if (isTRUE(markdown)) {
+        if (.isPrintCall(sysCalls)) {
+            result <- paste0(utils::capture.output(x$.catMarkdownText()), collapse = "\n")
+            return(knitr::asis_output(result))
+        }
+
+        if (showDesign) {
+            .addObjectToPipeOperatorQueue(x$.design)
+        }
+        .addObjectToPipeOperatorQueue(x)
+        return(invisible(x))
+    }
+
     if (showDesign) {
         print.ParameterSet(x$.design, ..., markdown = markdown)
     }
@@ -318,7 +340,9 @@ print.TrialDesignCharacteristics <- function(x, ..., markdown = FALSE, showDesig
 #' @template return_dataframe
 #'
 #' @examples
+#' \dontrun{
 #' as.data.frame(getDesignCharacteristics(getDesignGroupSequential()))
+#' }
 #'
 #' @export
 #'
@@ -466,6 +490,7 @@ TrialDesignFisher <- R6::R6Class("TrialDesignFisher",
                 "alpha",
                 "alpha0Vec",
                 "bindingFutility",
+                "directionUpper",
                 "sided",
                 "tolerance",
                 "iterations",
@@ -514,6 +539,8 @@ TrialDesignFisher <- R6::R6Class("TrialDesignFisher",
 #' @template field_betaSpent
 #' @template field_typeBetaSpending
 #' @template field_userBetaSpending
+#' @template field_efficacyStops
+#' @template field_futilityStops
 #' @template field_power
 #' @template field_twoSidedPower
 #' @template field_constantBoundsHP
@@ -552,6 +579,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
         betaSpent = NULL,
         typeBetaSpending = NULL,
         userBetaSpending = NULL,
+        efficacyStops = NULL,
+        futilityStops = NULL,
         power = NULL,
         twoSidedPower = NULL,
         constantBoundsHP = NULL,
@@ -573,6 +602,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
                 gammaB = NA_real_,
                 typeBetaSpending = C_TYPE_OF_DESIGN_BS_NONE,
                 userBetaSpending = NA_real_,
+                efficacyStops = NA,
+                futilityStops = NA,
                 power = NA_real_,
                 twoSidedPower = C_TWO_SIDED_POWER_DEFAULT,
                 constantBoundsHP = NA_real_,
@@ -591,6 +622,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
             self$gammaB <- gammaB
             self$typeBetaSpending <- typeBetaSpending
             self$userBetaSpending <- userBetaSpending
+            self$efficacyStops <- efficacyStops
+            self$futilityStops <- futilityStops
             self$power <- power
             self$twoSidedPower <- twoSidedPower
             self$constantBoundsHP <- constantBoundsHP
@@ -605,6 +638,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
             self$.setParameterType("delayedInformation", C_PARAM_NOT_APPLICABLE)
             self$.setParameterType("decisionCriticalValues", C_PARAM_NOT_APPLICABLE)
             self$.setParameterType("reversalProbabilities", C_PARAM_NOT_APPLICABLE)
+            self$.setParameterType("efficacyStops", C_PARAM_NOT_APPLICABLE)
+            self$.setParameterType("futilityStops", C_PARAM_NOT_APPLICABLE)
         },
         .formatComparisonResult = function(x) {
             if (is.null(x) || length(x) == 0 || !is.numeric(x)) {
@@ -617,8 +652,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
         },
         .pasteComparisonResult = function(name, newValue, oldValue) {
             return(paste0(
-                name, "_new = ", .arrayToString(.formatComparisonResult(newValue)), " (", .getClassName(newValue), "), ",
-                name, "_old = ", .arrayToString(.formatComparisonResult(oldValue)), " (", .getClassName(oldValue), ")"
+                name, "_new = ", .arrayToString(self$.formatComparisonResult(newValue)), " (", .getClassName(newValue), "), ",
+                name, "_old = ", .arrayToString(self$.formatComparisonResult(oldValue)), " (", .getClassName(oldValue), ")"
             ))
         },
         hasChanged = function(...,
@@ -705,7 +740,7 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
                     informationRatesTemp, self$informationRates
                 ))
             }
-            if (self$.getParameterType("futilityBounds") != C_PARAM_GENERATED &&
+            if (!self$isGeneratedParameter("futilityBounds") &&
                     (!grepl("^as.*", typeOfDesign) || typeBetaSpending == C_TYPE_OF_DESIGN_BS_NONE) &&
                     !identical(futilityBoundsTemp, self$futilityBounds)) {
                 return(self$.pasteComparisonResult(
@@ -787,6 +822,7 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
                 "deltaPT0",
                 "futilityBounds",
                 "bindingFutility",
+                "directionUpper",
                 "constantBoundsHP",
                 "gammaA",
                 "gammaB",
@@ -800,6 +836,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
                 "betaSpent",
                 "typeBetaSpending",
                 "userBetaSpending",
+                "efficacyStops",
+                "futilityStops",
                 "criticalValues",
                 "stageLevels",
                 "decisionCriticalValues",
@@ -841,6 +879,8 @@ TrialDesignInverseNormal <- R6::R6Class("TrialDesignInverseNormal",
 #' @template field_betaSpent
 #' @template field_typeBetaSpending
 #' @template field_userBetaSpending
+#' @template field_efficacyStops
+#' @template field_futilityStops
 #' @template field_power
 #' @template field_twoSidedPower
 #' @template field_constantBoundsHP
@@ -921,10 +961,14 @@ TrialDesignConditionalDunnett <- R6::R6Class("TrialDesignConditionalDunnett",
         informationAtInterim = NULL,
         secondStageConditioning = NULL,
         sided = NULL,
-        initialize = function(..., informationAtInterim = NULL, secondStageConditioning = NULL) {
+        initialize = function(...,
+                informationAtInterim = NULL,
+                secondStageConditioning = NULL,
+                directionUpper = NA) {
             super$initialize(...)
             self$informationAtInterim <- informationAtInterim
             self$secondStageConditioning <- secondStageConditioning
+            self$directionUpper <- directionUpper
             notApplicableParameters <- c(
                 "kMax",
                 "stages",
@@ -977,6 +1021,8 @@ TrialDesignConditionalDunnett <- R6::R6Class("TrialDesignConditionalDunnett",
 #'        If \code{secondStageConditioning = FALSE} is specified, the unconditional adjusted p-values are used, otherwise
 #'  	  conditional adjusted p-values are calculated, default is \code{secondStageConditioning = TRUE}
 #'        (for details, see Koenig et al., 2008).
+#' @inheritParams param_directionUpper
+#' @inheritParams param_three_dots
 #'
 #' @details
 #' For performing the conditional Dunnett test the design must be defined through this function.
@@ -994,15 +1040,24 @@ TrialDesignConditionalDunnett <- R6::R6Class("TrialDesignConditionalDunnett",
 #' @export
 #'
 getDesignConditionalDunnett <- function(alpha = 0.025, # C_ALPHA_DEFAULT
-        informationAtInterim = 0.5, secondStageConditioning = TRUE) {
+        informationAtInterim = 0.5,
+        ...,
+        secondStageConditioning = TRUE,
+        directionUpper = NA) {
     .assertIsValidAlpha(alpha)
     .assertIsSingleNumber(informationAtInterim, "informationAtInterim")
     .assertIsInOpenInterval(informationAtInterim, "informationAtInterim", 0, 1)
-    return(TrialDesignConditionalDunnett$new(
+    .assertIsSingleLogical(directionUpper, "directionUpper", naAllowed = TRUE)
+    design <- TrialDesignConditionalDunnett$new(
         alpha = alpha,
         informationAtInterim = informationAtInterim,
-        secondStageConditioning = secondStageConditioning
+        secondStageConditioning = secondStageConditioning,
+        directionUpper = directionUpper
+    )
+    design$.setParameterType("directionUpper", ifelse(!is.na(directionUpper),
+        C_PARAM_USER_DEFINED, C_PARAM_NOT_APPLICABLE
     ))
+    return(design)
 }
 
 #'
@@ -1075,11 +1130,86 @@ getDesignConditionalDunnett <- function(alpha = 0.025, # C_ALPHA_DEFAULT
 #'
 #' @export
 #'
-plot.TrialDesign <- function(x, y, ..., main = NA_character_,
-        xlab = NA_character_, ylab = NA_character_, type = 1L, palette = "Set1",
-        theta = seq(-1, 1, 0.01), nMax = NA_integer_, plotPointsEnabled = NA,
-        legendPosition = NA_integer_, showSource = FALSE,
-        grid = 1, plotSettings = NULL) {
+plot.TrialDesign <- function(
+        x,
+        y,
+        ...,
+        main = NA_character_,
+        xlab = NA_character_,
+        ylab = NA_character_,
+        type = 1L,
+        palette = "Set1",
+        theta = seq(-1, 1, 0.01),
+        nMax = NA_integer_,
+        plotPointsEnabled = NA,
+        legendPosition = NA_integer_,
+        showSource = FALSE,
+        grid = 1,
+        plotSettings = NULL) {
+    .assertIsValidPlotType(type, naAllowed = FALSE)
+    .assertIsSingleInteger(grid, "grid", naAllowed = FALSE, validateType = FALSE)
+    markdown <- .getOptionalArgument("markdown", ..., optionalArgumentDefaultValue = NA)
+    if (is.na(markdown)) {
+        markdown <- .isMarkdownEnabled("plot")
+    }
+    
+    .warnInCaseOfUnknownArguments(
+        functionName = "plot",
+        ignore = c("xlim", "ylim", "companyAnnotationEnabled", "variedParameters", 
+            "showFutilityBounds", "showAlphaSpent", "showBetaSpent"), ...
+    )
+    .showWarningIfPlotArgumentWillBeIgnored(type, ..., obj = x)
+
+    args <- list(
+        x = x,
+        y = NULL,
+        main = main,
+        xlab = xlab,
+        ylab = ylab,
+        type = type,
+        palette = palette,
+        theta = theta,
+        nMax = nMax,
+        plotPointsEnabled = plotPointsEnabled,
+        legendPosition = legendPosition,
+        showSource = showSource,
+        grid = grid,
+        plotSettings = plotSettings,
+        ...
+    )
+
+    if (markdown) {
+        sep <- .getMarkdownPlotPrintSeparator()
+        if (length(type) > 1 && grid == 1) {
+            grid <- 0
+            args$grid <- 0
+        }
+        if (grid > 0) {
+            print(do.call(.plot.TrialDesign, args))
+        } else {
+            do.call(.plot.TrialDesign, args)
+        }
+        return(.knitPrintQueue(x, sep = sep, prefix = sep))
+    }
+
+    return(do.call(.plot.TrialDesign, args))
+}
+
+.plot.TrialDesign <- function(x,
+        y,
+        ...,
+        main = NA_character_,
+        xlab = NA_character_,
+        ylab = NA_character_,
+        type = 1L,
+        palette = "Set1",
+        theta = seq(-1, 1, 0.01),
+        nMax = NA_integer_,
+        plotPointsEnabled = NA,
+        legendPosition = NA_integer_,
+        showSource = FALSE,
+        grid = 1,
+        plotSettings = NULL) {
     fCall <- match.call(expand.dots = FALSE)
     designName <- deparse(fCall$x)
     .assertGgplotIsInstalled()
@@ -1092,12 +1222,21 @@ plot.TrialDesign <- function(x, y, ..., main = NA_character_,
     plotList <- list()
     for (typeNumber in typeNumbers) {
         p <- .plotTrialDesign(
-            x = x, y = y, main = main,
-            xlab = xlab, ylab = ylab, type = typeNumber, palette = palette,
-            theta = theta, nMax = nMax, plotPointsEnabled = plotPointsEnabled,
+            x = x,
+            y = y,
+            main = main,
+            xlab = xlab,
+            ylab = ylab,
+            type = typeNumber,
+            palette = palette,
+            theta = theta,
+            nMax = nMax,
+            plotPointsEnabled = plotPointsEnabled,
             legendPosition = .getGridLegendPosition(legendPosition, typeNumbers, grid),
-            showSource = showSource, designName = designName,
-            plotSettings = plotSettings, ...
+            showSource = showSource,
+            designName = designName,
+            plotSettings = plotSettings,
+            ...
         )
         .printPlotShowSourceSeparator(showSource, typeNumber, typeNumbers)
         if (length(typeNumbers) > 1) {
@@ -1122,29 +1261,59 @@ plot.TrialDesign <- function(x, y, ..., main = NA_character_,
 
 #' @rdname plot.TrialDesign
 #' @export
-plot.TrialDesignCharacteristics <- function(x, y, ...) {
+plot.TrialDesignCharacteristics <- function(x, y, ..., type = 1L, grid = 1) {
+    .assertIsValidPlotType(type, naAllowed = FALSE)
+    .assertIsSingleInteger(grid, "grid", naAllowed = FALSE, validateType = FALSE)
+    markdown <- .getOptionalArgument("markdown", ..., optionalArgumentDefaultValue = NA)
+    if (is.na(markdown)) {
+        markdown <- .isMarkdownEnabled("plot")
+    }
+
+    if (markdown) {
+        sep <- .getMarkdownPlotPrintSeparator()
+        if (length(type) > 1 && grid == 1) {
+            grid <- 0
+            args$grid <- 0
+        }
+        if (grid > 0) {
+            print(.plot.TrialDesign(x = x$.design, y = y, type = type, grid = grid, ...))
+        } else {
+            .plot.TrialDesign(x = x$.design, y = y, type = type, grid = grid, ...)
+        }
+        return(.knitPrintQueue(x, sep = sep, prefix = sep))
+    }
+
     plot(x = x$.design, y = y, ...)
 }
 
-.plotTrialDesign <- function(..., x, y, main,
-        xlab, ylab, type, palette,
-        theta, nMax, plotPointsEnabled,
-        legendPosition, showSource, designName, plotSettings = NULL) {
+.plotTrialDesign <- function(
+        ..., 
+        x, 
+        y, 
+        main,
+        xlab, 
+        ylab, 
+        type, 
+        palette,
+        theta, 
+        nMax, 
+        plotPointsEnabled,
+        legendPosition, 
+        showSource, 
+        designName, 
+        plotSettings = NULL) {
+        
     .assertGgplotIsInstalled()
 
     .assertIsSingleInteger(type, "type", naAllowed = FALSE, validateType = FALSE)
     if (any(.isTrialDesignFisher(x)) && !(type %in% c(1, 3, 4))) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
-            "'type' (", type, ") is not allowed for Fisher designs; must be 1, 3 or 4"
+            "'type' (", type, ") is not allowed for Fisher designs; must be 1, 3 or 4",
+            call. = FALSE
         )
     }
 
-    .warnInCaseOfUnknownArguments(
-        functionName = "plot",
-        ignore = c("xlim", "ylim", "companyAnnotationEnabled", "variedParameters"), ...
-    )
-
     if ((type < 5 || type > 9) && !identical(theta, seq(-1, 1, 0.01))) {
         warning("'theta' (", .reconstructSequenceCommand(theta), ") ",
             "will be ignored for plot type ", type,
@@ -1164,7 +1333,8 @@ plot.TrialDesignCharacteristics <- function(x, y, ...) {
                 stop(
                     C_EXCEPTION_TYPE_MISSING_ARGUMENT,
                     "'variedParameters' needs to be specified, ",
-                    "e.g., variedParameters = \"typeOfDesign\""
+                    "e.g., variedParameters = \"typeOfDesign\"",
+                    call. = FALSE
                 )
             }
         }
@@ -1177,10 +1347,20 @@ plot.TrialDesignCharacteristics <- function(x, y, ...) {
     }
 
     .plotTrialDesignSet(
-        x = designSet, y = y, main = main, xlab = xlab, ylab = ylab, type = type,
-        palette = palette, theta = theta, nMax = nMax,
-        plotPointsEnabled = plotPointsEnabled, legendPosition = legendPosition,
-        showSource = showSource, designSetName = designName, ...
+        x = designSet,
+        y = y,
+        main = main,
+        xlab = xlab,
+        ylab = ylab,
+        type = type,
+        palette = palette,
+        theta = theta,
+        nMax = nMax,
+        plotPointsEnabled = plotPointsEnabled,
+        legendPosition = legendPosition,
+        showSource = showSource,
+        designSetName = designName,
+        ...
     )
 }
 
@@ -1203,7 +1383,9 @@ plot.TrialDesignCharacteristics <- function(x, y, ...) {
 #' @template return_dataframe
 #'
 #' @examples
+#' \dontrun{
 #' as.data.frame(getDesignGroupSequential())
+#' }
 #'
 #' @export
 #'
