@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7958 $
-## |  Last changed: $Date: 2024-05-30 09:56:27 +0200 (Do, 30 Mai 2024) $
+## |  File version: $Revision: 8612 $
+## |  Last changed: $Date: 2025-03-14 06:39:43 +0100 (Fr, 14 Mrz 2025) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -39,6 +39,7 @@ C_TRIAL_DESIGN_PLAN_DEFAULT_VALUES_MEANS <- list(
 
 C_TRIAL_DESIGN_PLAN_DEFAULT_VALUES_RATES <- list(
     normalApproximation = TRUE,
+    conservative = TRUE,
     riskRatio = FALSE,
     thetaH0 = 0,
     pi1 = C_PI_1_SAMPLE_SIZE_DEFAULT,
@@ -144,7 +145,8 @@ TrialDesignPlan <- R6::R6Class("TrialDesignPlan",
             if (length(objectType) == 0 || !(objectType %in% c("sampleSize", "power"))) {
                 stop(
                     C_EXCEPTION_TYPE_RUNTIME_ISSUE, "'.objectType' (", objectType,
-                    ") must be specified as 'sampleSize' or 'power'"
+                    ") must be specified as 'sampleSize' or 'power'", 
+                    call. = FALSE
                 )
             }
             self$.objectType <- objectType
@@ -153,7 +155,8 @@ TrialDesignPlan <- R6::R6Class("TrialDesignPlan",
             if (length(self$.objectType) == 0 || !(self$.objectType %in% c("sampleSize", "power"))) {
                 stop(
                     C_EXCEPTION_TYPE_RUNTIME_ISSUE,
-                    "'.objectType' must be specified as 'sampleSize' or 'power'"
+                    "'.objectType' must be specified as 'sampleSize' or 'power'", 
+                    call. = FALSE
                 )
             }
             return(self$.objectType == "sampleSize")
@@ -162,7 +165,8 @@ TrialDesignPlan <- R6::R6Class("TrialDesignPlan",
             if (length(self$.objectType) == 0 || !(self$.objectType %in% c("sampleSize", "power"))) {
                 stop(
                     C_EXCEPTION_TYPE_RUNTIME_ISSUE,
-                    "'.objectType' must be specified as 'sampleSize' or 'power'"
+                    "'.objectType' must be specified as 'sampleSize' or 'power'", 
+                    call. = FALSE
                 )
             }
             return(self$.objectType == "power")
@@ -285,8 +289,10 @@ TrialDesignPlan <- R6::R6Class("TrialDesignPlan",
 #' @template return_dataframe
 #'
 #' @examples
+#' \dontrun{
 #' as.data.frame(getSampleSizeMeans())
-#'
+#' }
+#' 
 #' @export
 #'
 #' @keywords internal
@@ -494,6 +500,7 @@ TrialDesignPlanMeans <- R6::R6Class("TrialDesignPlanMeans",
 #' @template field_riskRatio
 #' @template field_thetaH0
 #' @template field_normalApproximation
+#' @template field_conservative
 #' @template field_pi1
 #' @template field_pi2
 #' @template field_groups
@@ -548,6 +555,7 @@ TrialDesignPlanRates <- R6::R6Class("TrialDesignPlanRates",
         riskRatio = NULL,
         thetaH0 = NULL,
         normalApproximation = NULL,
+        conservative = NULL,
         pi1 = NULL,
         pi2 = NULL,
         groups = NULL,
@@ -640,7 +648,8 @@ TrialDesignPlanRates <- R6::R6Class("TrialDesignPlanRates",
                     pi1 = pi1Temp,
                     pi2 = self$.getParameterValueIfUserDefinedOrDefault("pi2"),
                     groups = self$.getParameterValueIfUserDefinedOrDefault("groups"),
-                    allocationRatioPlanned = self$.getParameterValueIfUserDefinedOrDefault("allocationRatioPlanned")
+                    allocationRatioPlanned = self$.getParameterValueIfUserDefinedOrDefault("allocationRatioPlanned"),
+                    conservative = self$.getParameterValueIfUserDefinedOrDefault("conservative")
                 ))
             } else {
                 return(getPowerRates(
@@ -900,7 +909,7 @@ TrialDesignPlanSurvival <- R6::R6Class("TrialDesignPlanSurvival",
                 ), call. = FALSE)
             }
         },
-        recreate = function(hazardRatio = NA_real_, pi1 = NA_real_) {
+        recreate = function(..., hazardRatio = NA_real_, pi1 = NA_real_, maxNumberOfSubjects = NA_integer_) {
             hr <- NA_real_
             if (self$.getParameterType("hazardRatio") == C_PARAM_USER_DEFINED) {
                 hr <- hazardRatio
@@ -933,57 +942,44 @@ TrialDesignPlanSurvival <- R6::R6Class("TrialDesignPlanSurvival",
             if (all(is.na(accrualIntensityTemp))) {
                 accrualIntensityTemp <- C_ACCRUAL_INTENSITY_DEFAULT
             }
-
+            
+            if (is.null(maxNumberOfSubjects) || length(maxNumberOfSubjects) != 1 || is.na(maxNumberOfSubjects)) {
+                maxNumberOfSubjects <- self$.getParameterValueIfUserDefinedOrDefault("maxNumberOfSubjects")
+            }
+            
+            args <- list(
+                design = self$.design,
+                typeOfComputation = self$.getParameterValueIfUserDefinedOrDefault("typeOfComputation"),
+                thetaH0 = self$.getParameterValueIfUserDefinedOrDefault("thetaH0"),
+                pi1 = pi1Temp,
+                pi2 = self$.getParameterValueIfUserDefinedOrDefault("pi2"),
+                allocationRatioPlanned = self$allocationRatioPlanned,
+                eventTime = ifelse(all(is.na(self$eventTime)), C_EVENT_TIME_DEFAULT, self$eventTime),
+                accrualTime = accrualTimeTemp,
+                accrualIntensity = accrualIntensityTemp,
+                kappa = self$kappa,
+                piecewiseSurvivalTime = self$.getParameterValueIfUserDefinedOrDefault("piecewiseSurvivalTime"),
+                lambda2 = lambda2,
+                lambda1 = self$.getParameterValueIfUserDefinedOrDefault("lambda1"),
+                hazardRatio = hr,
+                maxNumberOfSubjects = maxNumberOfSubjects,
+                dropoutRate1 = self$dropoutRate1,
+                dropoutRate2 = self$dropoutRate2,
+                dropoutTime = self$dropoutTime
+            )
+            
             if (self$.objectType == "sampleSize") {
-                return(getSampleSizeSurvival(
-                    design = self$.design,
-                    typeOfComputation = self$.getParameterValueIfUserDefinedOrDefault("typeOfComputation"),
-                    thetaH0 = self$.getParameterValueIfUserDefinedOrDefault("thetaH0"),
-                    pi1 = pi1Temp,
-                    pi2 = self$.getParameterValueIfUserDefinedOrDefault("pi2"),
-                    allocationRatioPlanned = self$allocationRatioPlanned,
-                    accountForObservationTimes = self$.getParameterValueIfUserDefinedOrDefault("accountForObservationTimes"),
-                    eventTime = ifelse(all(is.na(self$eventTime)), C_EVENT_TIME_DEFAULT, self$eventTime),
-                    accrualTime = accrualTimeTemp,
-                    accrualIntensity = accrualIntensityTemp,
-                    kappa = self$kappa,
-                    piecewiseSurvivalTime = self$.getParameterValueIfUserDefinedOrDefault("piecewiseSurvivalTime"),
-                    lambda2 = lambda2,
-                    lambda1 = self$.getParameterValueIfUserDefinedOrDefault("lambda1"),
-                    followUpTime = self$.getParameterValueIfUserDefinedOrDefault("followUpTime"),
-                    maxNumberOfSubjects = self$.getParameterValueIfUserDefinedOrDefault("maxNumberOfSubjects"),
-                    dropoutRate1 = self$dropoutRate1,
-                    dropoutRate2 = self$dropoutRate2,
-                    dropoutTime = self$dropoutTime,
-                    hazardRatio = hr
-                ))
+                args$ accountForObservationTimes = self$.getParameterValueIfUserDefinedOrDefault("accountForObservationTimes")
+                args$followUpTime = self$.getParameterValueIfUserDefinedOrDefault("followUpTime")
+                return(do.call(getSampleSizeSurvival, args))
             } else {
                 directionUpperTemp <- self$directionUpper
                 if (length(directionUpperTemp) > 1) {
                     directionUpperTemp <- directionUpperTemp[1]
                 }
-                return(getPowerSurvival(
-                    design = self$.design,
-                    typeOfComputation = self$.getParameterValueIfUserDefinedOrDefault("typeOfComputation"),
-                    thetaH0 = self$.getParameterValueIfUserDefinedOrDefault("thetaH0"),
-                    pi1 = pi1Temp,
-                    pi2 = self$.getParameterValueIfUserDefinedOrDefault("pi2"),
-                    directionUpper = directionUpperTemp,
-                    allocationRatioPlanned = self$allocationRatioPlanned,
-                    eventTime = ifelse(all(is.na(self$eventTime)), C_EVENT_TIME_DEFAULT, self$eventTime),
-                    accrualTime = accrualTimeTemp,
-                    accrualIntensity = accrualIntensityTemp,
-                    kappa = self$kappa,
-                    piecewiseSurvivalTime = self$.getParameterValueIfUserDefinedOrDefault("piecewiseSurvivalTime"),
-                    lambda2 = lambda2,
-                    lambda1 = self$.getParameterValueIfUserDefinedOrDefault("lambda1"),
-                    hazardRatio = hr,
-                    maxNumberOfSubjects = self$.getParameterValueIfUserDefinedOrDefault("maxNumberOfSubjects"),
-                    maxNumberOfEvents = self$.getParameterValueIfUserDefinedOrDefault("maxNumberOfEvents"),
-                    dropoutRate1 = self$dropoutRate1,
-                    dropoutRate2 = self$dropoutRate2,
-                    dropoutTime = self$dropoutTime
-                ))
+                args$directionUpper = directionUpperTemp
+                args$maxNumberOfEvents = self$.getParameterValueIfUserDefinedOrDefault("maxNumberOfEvents")
+                return(do.call(getPowerSurvival, args))
             }
         }
     )
@@ -1086,8 +1082,15 @@ TrialDesignPlanCountData <- R6::R6Class("TrialDesignPlanCountData",
         expectedInformationH0 = NULL,
         expectedInformationH01 = NULL,
         expectedInformationH1 = NULL,
-        maxInformation = NULL,
+        criticalValuesEffectScale = matrix(),
+        criticalValuesEffectScaleLower = NULL,
+        criticalValuesEffectScaleUpper = NULL,
+        criticalValuesPValueScale = NULL,
+        futilityBoundsEffectScale = NULL,
+        futilityBoundsEffectScaleLower = NULL,
+        futilityBoundsEffectScaleUpper = NULL,
         futilityBoundsPValueScale = NULL,
+        maxInformation = NULL,
         initialize = function(...,
                 designCharacteristics,
                 lambda1 = NA_real_,
@@ -1120,6 +1123,14 @@ TrialDesignPlanCountData <- R6::R6Class("TrialDesignPlanCountData",
             self$.setParameterType("groups", C_PARAM_NOT_APPLICABLE)
             self$.setParameterType("directionUpper", C_PARAM_NOT_APPLICABLE)
             self$.setParameterType("optimumAllocationRatio", C_PARAM_NOT_APPLICABLE)
+            
+            self$.setParameterType("criticalValuesEffectScale", C_PARAM_NOT_APPLICABLE)
+            self$.setParameterType("criticalValuesEffectScaleLower", C_PARAM_NOT_APPLICABLE)
+            self$.setParameterType("criticalValuesEffectScaleUpper", C_PARAM_NOT_APPLICABLE)
+            
+            self$.setParameterType("futilityBoundsEffectScale", C_PARAM_NOT_APPLICABLE)
+            self$.setParameterType("futilityBoundsEffectScaleLower", C_PARAM_NOT_APPLICABLE)
+            self$.setParameterType("futilityBoundsEffectScaleUpper", C_PARAM_NOT_APPLICABLE)
         },
         .toString = function(startWithUpperCase = FALSE) {
             s <- "count data"
