@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8274 $
-## |  Last changed: $Date: 2024-09-26 11:33:59 +0200 (Do, 26 Sep 2024) $
+## |  File version: $Revision: 8752 $
+## |  Last changed: $Date: 2025-07-10 14:29:45 +0200 (Do, 10 Jul 2025) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -41,6 +41,7 @@ C_POSITION_LEFT_BOTTOM <- 3
 C_POSITION_RIGHT_TOP <- 4
 C_POSITION_RIGHT_CENTER <- 5
 C_POSITION_RIGHT_BOTTOM <- 6
+C_POSITION_OUTSIDE_BOTTOM <- "bottom"
 
 C_DESIGN_TOLERANCE_DEFAULT <- 1e-08
 C_CONST_NEWTON_COTES <- 15
@@ -55,6 +56,8 @@ C_KMAX_DEFAULT <- 3L
 C_KMAX_UPPER_BOUND <- 50L
 C_KMAX_UPPER_BOUND_FISHER <- 6L
 
+C_MAX_NUMBER_OF_EFFECTS <- 50L
+
 C_NA_MAX_DEFAULT <- 100L
 C_POWER_ASN_THETA_DEFAULT <- seq(-1, 1, 0.02)
 
@@ -136,11 +139,13 @@ C_INTERSECTION_TESTS_ENRICHMENT <- c(
     "Sidak",
     "SpiessensDebois"
 )
+C_RATES_STD_ERROR_ESTIMATE <- c("pooled", "unpooled")
+C_RATES_STD_ERROR_ESTIMATE_DEFAULT <- "pooled"
 C_VARIANCE_OPTION_DUNNETT <- "overallPooled"
-C_VARIANCE_OPTION_MULTIARMED_DEFAULT <- "overallPooled"
 C_VARIANCE_OPTIONS_MULTIARMED <- c("overallPooled", "pairwisePooled", "notPooled")
-C_VARIANCE_OPTION_ENRICHMENT_DEFAULT <- "pooled"
+C_VARIANCE_OPTION_MULTIARMED_DEFAULT <- "overallPooled"
 C_VARIANCE_OPTIONS_ENRICHMENT <- c("pooled", "notPooled", "pooledFromFull")
+C_VARIANCE_OPTION_ENRICHMENT_DEFAULT <- "pooled"
 C_STRATIFIED_ANALYSIS_DEFAULT <- TRUE
 
 #
@@ -456,6 +461,7 @@ C_PARAMETER_NAMES <- createDictionary("C_PARAMETER_NAMES", list(
     theta = "Effect",
     direction = "Direction",
     normalApproximation = "Normal approximation",
+    conservative = "Conservative",
     equalVariances = "Equal variances",
     shift = "Shift",
     inflationFactor = "Inflation factor",
@@ -555,6 +561,7 @@ C_PARAMETER_NAMES <- createDictionary("C_PARAMETER_NAMES", list(
     accountForObservationTimes = "Account for observation times",
     eventTime = "Event time",
     accrualTime = "Accrual time",
+    accrualTimeOriginal = "Accrual time",
     totalAccrualTime = "Total accrual time",
     remainingTime = "Remaining time",
     followUpTime = "Follow up time",
@@ -621,6 +628,7 @@ C_PARAMETER_NAMES <- createDictionary("C_PARAMETER_NAMES", list(
     singleEventsPerStage = "Single number of events",
     singleEventsPerArmAndStage = "Single number of events",
     singleEventsPerSubsetAndStage = "Single number of events",
+	populationEventsPerStage = "Number of events per population",
     endOfAccrualIsUserDefined = "End of accrual is user defined",
     followUpTimeMustBeUserDefined = "Follow-up time must be user defined",
     maxNumberOfSubjectsIsUserDefined = "Max number of subjects is user defined",
@@ -649,6 +657,7 @@ C_PARAMETER_NAMES <- createDictionary("C_PARAMETER_NAMES", list(
     typeOfShape = "Type of shape",
     gED50 = "ED50",
     slope = "Slope",
+    doseLevels = "Dose levels",
     adaptations = "Adaptations",
     typeOfSelection = "Type of selection",
     effectMeasure = "Effect measure",
@@ -712,13 +721,16 @@ C_PARAMETER_NAMES <- createDictionary("C_PARAMETER_NAMES", list(
     expectedInformationH0 = "Expected information under H0",
     expectedInformationH01 = "Expected information under H0/H1",
     expectedInformationH1 = "Expected information under H1",
-    plannedCalendarTime = "Planned calendar time"
+    plannedCalendarTime = "Planned calendar time",
+    efficacyStops = "Efficacy stops",
+    futilityStops = "Futility stops",
+    stdErrorEstimate = "Standard error estimate"
 ))
 
 C_TABLE_COLUMN_NAMES <- createDictionary("C_TABLE_COLUMN_NAMES", list(
     iterations = "Iterations",
     seed = "Seed",
-    groups = "Treatment group",
+    groups = "Treatment groups",
     stages = "Stage",
     sampleSizes = "Sample size",
     means = "Mean",
@@ -771,6 +783,7 @@ C_TABLE_COLUMN_NAMES <- createDictionary("C_TABLE_COLUMN_NAMES", list(
     theta = "Effect",
     direction = "Direction",
     normalApproximation = "Normal approximation",
+    conservative = "Conservative",
     equalVariances = "Equal variance",
     assumedStDev = "Assumed standard deviation",
     assumedStDevs = "Assumed standard deviation",
@@ -866,6 +879,7 @@ C_TABLE_COLUMN_NAMES <- createDictionary("C_TABLE_COLUMN_NAMES", list(
     accountForObservationTimes = "Account for observation times",
     eventTime = "Event time",
     accrualTime = "Accrual time",
+    accrualTimeOriginal = "Accrual time",
     totalAccrualTime = "Total accrual time",
     remainingTime = "Remaining time",
     followUpTime = "Follow up time",
@@ -958,6 +972,7 @@ C_TABLE_COLUMN_NAMES <- createDictionary("C_TABLE_COLUMN_NAMES", list(
     typeOfShape = "Type of shape",
     gED50 = "ED50",
     slope = "Slope",
+    doseLevels = "Dose levels",
     adaptations = "Adaptations",
     typeOfSelection = "Type of selection",
     effectMeasure = "Effect measure",
@@ -1017,7 +1032,10 @@ C_TABLE_COLUMN_NAMES <- createDictionary("C_TABLE_COLUMN_NAMES", list(
     expectedInformationH0 = "Expected information under H0",
     expectedInformationH01 = "Expected information under H0/H1",
     expectedInformationH1 = "Expected information under H1",
-    plannedCalendarTime = "Planned calendar time"
+    plannedCalendarTime = "Planned calendar time",
+    efficacyStops = "Efficacy stops",
+    futilityStops = "Futility stops",
+    stdErrorEstimate = "Standard error estimate"
 ))
 
 C_PARAMETER_NAMES_PLOT_SETTINGS <- createDictionary("C_PARAMETER_NAMES_PLOT_SETTINGS", list(
@@ -1034,15 +1052,15 @@ C_PARAMETER_NAMES_PLOT_SETTINGS <- createDictionary("C_PARAMETER_NAMES_PLOT_SETT
     if (inherits(obj, "TrialDesignSet") && length(obj$designs) > 0) {
         obj <- obj$designs[[1]]
     }
-    
+
     if (!inherits(obj, "TrialDesign")) {
         obj <- obj[[".design"]]
     }
-    
+
     if (is.null(obj) || !inherits(obj, "TrialDesign")) {
         return(parameterName)
     }
-    
+
     if (identical(parameterName, "futilityBounds")) {
         if (.isDelayedInformationEnabled(design = obj)) {
             if (!is.na(obj$bindingFutility) && !obj$bindingFutility) {
@@ -1070,7 +1088,7 @@ C_PARAMETER_NAMES_PLOT_SETTINGS <- createDictionary("C_PARAMETER_NAMES_PLOT_SETT
 
 .getParameterCaption <- function(parameterName, obj = NULL, ..., tableOutputEnabled = FALSE) {
     .assertIsSingleCharacter(parameterName, "parameterName")
-    
+
     if (grepl("\\$", parameterName)) {
         parts <- strsplit(parameterName, "\\$", fixed = TRUE)[[1]]
         if (length(parts) == 2) {
@@ -1080,7 +1098,7 @@ C_PARAMETER_NAMES_PLOT_SETTINGS <- createDictionary("C_PARAMETER_NAMES_PLOT_SETT
             parameterName <- parts[2]
         }
     }
-    
+
     if (is.null(obj)) {
         if (tableOutputEnabled) {
             return(C_TABLE_COLUMN_NAMES[[parameterName]])
@@ -1088,7 +1106,7 @@ C_PARAMETER_NAMES_PLOT_SETTINGS <- createDictionary("C_PARAMETER_NAMES_PLOT_SETT
 
         return(C_PARAMETER_NAMES[[parameterName]])
     }
-    
+
     parameterName <- .getParameterNameTrialDesign(parameterName, obj)
 
     if (inherits(obj, "PlotSettings")) {
@@ -1096,7 +1114,7 @@ C_PARAMETER_NAMES_PLOT_SETTINGS <- createDictionary("C_PARAMETER_NAMES_PLOT_SETT
     }
 
     parameterName <- .getParameterNameTrialDesign(parameterName, obj)
-    
+
     pluralExt <- ifelse(tableOutputEnabled, "", "s")
 
     if (identical(parameterName, "futilityBounds") &&
@@ -1143,22 +1161,13 @@ C_PARAMETER_NAMES_PLOT_SETTINGS <- createDictionary("C_PARAMETER_NAMES_PLOT_SETT
     }
 
     if (inherits(obj, "AnalysisResults")) {
-        if (identical(parameterName, "repeatedConfidenceIntervalLowerBounds")) {
-            if (.isTrialDesignConditionalDunnett(obj$.design)) {
-                return(paste0("Overall confidence interval", pluralExt, " (lower)"))
-            } else {
-                return(paste0("Confidence interval", pluralExt, " (lower)"))
-            }
+        if (identical(parameterName, "repeatedConfidenceIntervalLowerBounds") &&
+                .isTrialDesignConditionalDunnett(obj$.design)) {
+            return(paste0("Overall confidence interval", pluralExt, " (lower)"))
         }
-        if (identical(parameterName, "repeatedConfidenceIntervalUpperBounds")) {
-            if (.isTrialDesignConditionalDunnett(obj$.design)) {
-                return(paste0("Overall confidence interval", pluralExt, " (upper)"))
-            } else {
-                return(paste0("Confidence interval", pluralExt, " (upper)"))
-            }
-        }
-        if (identical(parameterName, "repeatedPValues")) {
-            return(paste0("Overall p-value", pluralExt))
+        if (identical(parameterName, "repeatedConfidenceIntervalUpperBounds") &&
+                .isTrialDesignConditionalDunnett(obj$.design)) {
+            return(paste0("Overall confidence interval", pluralExt, " (upper)"))
         }
     }
 
@@ -1210,12 +1219,26 @@ C_PARAMETER_NAMES_PLOT_SETTINGS <- createDictionary("C_PARAMETER_NAMES_PLOT_SETT
         return(".formatCriticalValuesFisher")
     }
 
-    if (parameterName == "accrualTime" && inherits(obj, "TrialDesignPlanCountData")) {
-        if (obj$.getParameterType("accrualTime") == C_PARAM_USER_DEFINED) {
-            return(".formatHowItIs")
-        }
+    if (parameterName == "accrualTime" && inherits(obj, "TrialDesignPlanCountData") &&
+            obj$.getParameterType("accrualTime") == C_PARAM_USER_DEFINED) {
+        return(".formatHowItIs")
     }
-
+    
+    if (parameterName == "accrualTimeOriginal" && inherits(obj, "TrialDesignPlanCountData") &&
+            obj$.getParameterType("accrualTimeOriginal") == C_PARAM_USER_DEFINED) {
+        return(".formatHowItIs")
+    }
+    
+    if (parameterName == "userAlphaSpending" && 
+            obj$.getParameterType("userAlphaSpending") == C_PARAM_GENERATED) {
+        return(".formatProbabilities")
+    }
+    
+    if (parameterName == "userBetaSpending" && 
+            obj$.getParameterType("userBetaSpending") == C_PARAM_GENERATED) {
+        return(".formatProbabilities")
+    }
+    
     return(C_PARAMETER_FORMAT_FUNCTIONS[[parameterName]])
 }
 
@@ -1320,6 +1343,7 @@ C_PARAMETER_FORMAT_FUNCTIONS <- createDictionary("C_PARAMETER_FORMAT_FUNCTIONS",
     lambda1 = ".formatRates",
     eventTime = ".formatEventTime",
     accrualTime = ".formatTime",
+    accrualTimeOriginal = ".formatTime",
     totalAccrualTime = ".formatTime",
     remainingTime = ".formatTime",
     followUpTime = ".formatTime",
@@ -1388,6 +1412,7 @@ C_PARAMETER_FORMAT_FUNCTIONS <- createDictionary("C_PARAMETER_FORMAT_FUNCTIONS",
     effectMatrix = ".formatMeans",
     gED50 = ".formatHowItIs",
     slope = ".formatHowItIs",
+    doseLevels = ".formatHowItIs",
     epsilonValue = ".formatHowItIs",
     threshold = ".formatHowItIs",
     rejectAtLeastOne = ".formatProbabilities",
