@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7940 $
-## |  Last changed: $Date: 2024-05-27 15:47:41 +0200 (Mo, 27 Mai 2024) $
+## |  File version: $Revision: 8765 $
+## |  Last changed: $Date: 2025-07-22 08:09:47 +0200 (Di, 22 Jul 2025) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -33,13 +33,20 @@ NULL
         {
             return(environmentName(environment(base::get(functionName))))
         },
-        error = function(e) {
-            return(NA_character_)
-        }
+        error = function(e) {}
     )
+    return(NA_character_)
 }
 
 .toCapitalized <- function(x, ignoreBlackList = FALSE) {
+    result <- character()
+    for (s in x) {
+        result <- c(result, .toCapitalizedSingleCharacter(s, ignoreBlackList = ignoreBlackList))
+    }
+    return(result)
+}
+
+.toCapitalizedSingleCharacter <- function(x, ignoreBlackList = FALSE) {
     if (is.null(x) || is.na(x) || !is.character(x)) {
         return(x)
     }
@@ -68,7 +75,7 @@ NULL
     indices <- gregexpr("[A-Z]", x)[[1]]
     parts <- strsplit(x, "[A-Z]")[[1]]
     result <- ""
-    for (i in 1:length(indices)) {
+    for (i in seq_len(length(indices))) {
         index <- indices[i]
         y <- tolower(substring(x, index, index))
         if (title) {
@@ -103,10 +110,15 @@ NULL
 }
 
 .firstCharacterToUpperCase <- function(x, ..., sep = "") {
+    if (is.null(x) || length(x) == 0) {
+        return(x)
+    }
+
     args <- list(...)
     if (length(args) > 0) {
-        x <- paste(x, unlist(args, use.names = FALSE), collapse = sep, sep = sep)
+        x <- paste(c(x, unlist(args, use.names = FALSE)), collapse = sep, sep = sep)
     }
+    x <- as.character(x)
     substr(x, 1, 1) <- toupper(substr(x, 1, 1))
     return(x)
 }
@@ -133,11 +145,13 @@ NULL
 #' @return the value of the optional argument if it exists; NULL otherwise.
 #'
 #' @examples
+#' \dontrun{
 #' f <- function(...) {
 #'     print(.getOptionalArgument("x", ...))
 #' }
 #' f(x = 1)
 #' f(y = 1)
+#' }
 #'
 #' @keywords internal
 #'
@@ -166,7 +180,7 @@ NULL
             if (length(arg) > 1) {
                 return(FALSE)
             }
-            
+
             return(is.na(arg))
         },
         warning = function(w) {
@@ -178,7 +192,7 @@ NULL
             return(FALSE)
         }
     )
-    
+
     return(FALSE)
 }
 
@@ -215,7 +229,7 @@ NULL
             if (length(arg) > 1) {
                 return(TRUE)
             }
-            
+
             return(!is.na(arg))
         },
         warning = function(e) {
@@ -249,13 +263,14 @@ NULL
     }
 
     space <- ifelse(grepl(" $", separator), "", " ")
-    part1 <- x[1:length(x) - 1]
+    part1 <- x[seq_len(length(x)) - 1]
     part2 <- x[length(x)]
     return(paste0(paste(part1, collapse = separator), separator, space, mode, " ", part2))
 }
 
 #'
 #' @examples
+#' \dontrun{
 #' .getConcatenatedValues(1)
 #' .getConcatenatedValues(1:2)
 #' .getConcatenatedValues(1:3)
@@ -271,6 +286,7 @@ NULL
 #' .getConcatenatedValues(1, mode = "or", separator = ";")
 #' .getConcatenatedValues(1:2, mode = "or", separator = ";")
 #' .getConcatenatedValues(1:3, mode = "or", separator = ";")
+#' }
 #'
 #' @noRd
 #'
@@ -898,6 +914,7 @@ NULL
 #'
 #' @param inclusiveR If \code{TRUE} (default) the information on how to cite the base R system in publications will be added.
 #' @param language Language code to use for the output, default is "en".
+#' @param markdown If \code{TRUE}, the output will be created in Markdown.
 #'
 #' @details
 #' This function shows how to cite \code{rpact} and \code{R} (\code{inclusiveR = TRUE}) in publications.
@@ -909,7 +926,22 @@ NULL
 #'
 #' @export
 #'
-printCitation <- function(inclusiveR = TRUE, language = "en") {
+printCitation <- function(inclusiveR = TRUE, language = "en", markdown = NA) {
+    if (is.na(markdown)) {
+        markdown <- .isMarkdownEnabled("print")
+    }
+
+    if (isTRUE(markdown)) {
+        result <- paste0(utils::capture.output(.printCitation(
+            inclusiveR = inclusiveR, language = language
+        )), collapse = "\n")
+        return(knitr::asis_output(result))
+    }
+
+    .printCitation(inclusiveR = inclusiveR, language = language)
+}
+
+.printCitation <- function(inclusiveR = TRUE, language = "en") {
     currentLanguage <- Sys.getenv("LANGUAGE")
     tryCatch(
         {
@@ -923,7 +955,7 @@ printCitation <- function(inclusiveR = TRUE, language = "en") {
                     index <- indices[length(indices)]
                     citR <- citR[1:min(index, length(citR))]
                 }
-                cat("\n", trimws(paste(citR, collapse = "\n")), "\n", sep = "")
+                cat("\n", trimws(paste(citR, collapse = "\n")), "\n\n", sep = "")
             }
 
             print(citation("rpact"), bibtex = FALSE)
@@ -981,7 +1013,7 @@ printCitation <- function(inclusiveR = TRUE, language = "en") {
     return(as.character(x))
 }
 
-.getFunctionAsString <- function(fun, stringWrapPrefix = " ", stringWrapParagraphWidth = 90) {
+.getFunctionAsString <- function(fun, stringWrapPrefix = " ") {
     .assertIsFunction(fun)
 
     s <- utils::capture.output(print(fun))
@@ -991,9 +1023,6 @@ printCitation <- function(inclusiveR = TRUE, language = "en") {
         stringWrapPrefix <- " "
     }
     s <- gsub("\u0009", stringWrapPrefix, s) # \t
-    if (!is.null(stringWrapParagraphWidth) && !is.na(stringWrapParagraphWidth)) {
-        # s <- paste0(s, collapse = "\n")
-    }
     return(s)
 }
 
@@ -1033,6 +1062,9 @@ printCitation <- function(inclusiveR = TRUE, language = "en") {
 #' @description
 #' Returns the parameter caption for a given object and parameter name.
 #'
+#' @param obj The rpact result object.
+#' @param var The variable/parameter name.
+#'
 #' @details
 #' This function identifies and returns the caption that will be used in print outputs of an rpact result object.
 #'
@@ -1043,19 +1075,69 @@ printCitation <- function(inclusiveR = TRUE, language = "en") {
 #' Returns \code{NULL} if the specified \code{parameterName} does not exist.
 #'
 #' @examples
+#' \dontrun{
 #' getParameterCaption(getDesignInverseNormal(), "kMax")
+#' }
 #'
 #' @keywords internal
 #'
 #' @export
 #'
-getParameterCaption <- function(obj, parameterName) {
+getParameterCaption <- function(obj, var) {
+    fCall <- match.call(expand.dots = FALSE)
     if (is.null(obj) || !.isResultObjectBaseClass(obj) || !inherits(obj, "FieldSet")) {
-        stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'obj' (", .getClassName(obj), ") must be an rpact result object")
+        stop(
+            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'obj' ",
+            "(", .getClassName(obj), ") must be an rpact result object"
+        )
     }
+    parameterName <- .getParameterSetVar(fCall, var)
+    .assertIsSingleCharacter(parameterName, "parameterName", naAllowed = FALSE)
+    return(.getParameterCaption(parameterName, obj))
+}
+
+#'
+#' @title
+#' Get Parameter Type
+#'
+#' @description
+#' Returns the parameter type for a given object and parameter name.
+#'
+#' @param obj The rpact result object.
+#' @param var The variable/parameter name.
+#'
+#' @details
+#' This function identifies and returns the type that will be used in print outputs of an rpact result object.
+#'
+#' @seealso
+#' \code{\link[=getParameterName]{getParameterName()}} for getting the parameter name for a given caption.
+#' \code{\link[=getParameterCaption]{getParameterCaption()}} for getting the parameter caption for a given name.
+#'
+#' @return Returns a \code{\link[base]{character}} of specifying the corresponding type of a given parameter name.
+#' Returns \code{NULL} if the specified \code{parameterName} does not exist.
+#'
+#' @examples
+#' \dontrun{
+#' getParameterType(getDesignInverseNormal(), "kMax")
+#' }
+#'
+#' @keywords internal
+#'
+#' @export
+#'
+getParameterType <- function(obj, var) {
+    fCall <- match.call(expand.dots = FALSE)
+    parameterName <- .getParameterSetVar(fCall, var)
+    if (is.null(obj) || !.isResultObjectBaseClass(obj) || !inherits(obj, "FieldSet")) {
+        stop(
+            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'obj' ",
+            "(", .getClassName(obj), ") must be an rpact result object"
+        )
+    }
+
     .assertIsSingleCharacter(parameterName, "parameterName", naAllowed = FALSE)
 
-    return(.getParameterCaption(parameterName, obj))
+    obj$.getParameterType(parameterName)
 }
 
 #'
@@ -1065,6 +1147,9 @@ getParameterCaption <- function(obj, parameterName) {
 #' @description
 #' Returns the parameter name for a given object and parameter caption.
 #'
+#' @param obj The rpact result object.
+#' @param parameterCaption The parameter caption.
+#'
 #' @details
 #' This function identifies and returns the parameter name for a given caption
 #' that will be used in print outputs of an rpact result object.
@@ -1076,7 +1161,9 @@ getParameterCaption <- function(obj, parameterName) {
 #' Returns \code{NULL} if the specified \code{parameterCaption} does not exist.
 #'
 #' @examples
+#' \dontrun{
 #' getParameterName(getDesignInverseNormal(), "Maximum number of stages")
+#' }
 #'
 #' @keywords internal
 #'
@@ -1084,21 +1171,28 @@ getParameterCaption <- function(obj, parameterName) {
 #'
 getParameterName <- function(obj, parameterCaption) {
     if (is.null(obj) || !.isResultObjectBaseClass(obj) || !inherits(obj, "FieldSet")) {
-        stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'obj' (", .getClassName(obj), ") must be an rpact result object")
+        stop(
+            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'obj' ",
+            "(", .getClassName(obj), ") must be an rpact result object"
+        )
     }
     .assertIsSingleCharacter(parameterCaption, "parameterCaption", naAllowed = FALSE)
+    parameterCaption <- trimws(parameterCaption)
+    if (parameterCaption %in% names(obj)) {
+        return(parameterCaption)
+    }
 
+    fieldNames <- obj$.getVisibleFieldNames()
     parameterName <- getDictionaryKeyByValue(C_PARAMETER_NAMES, parameterCaption)
-    if (!is.null(parameterName)) {
+    if (!is.null(parameterName) && length(parameterName) == 1 && parameterName %in% fieldNames) {
         return(parameterName)
     }
 
     parameterName <- getDictionaryKeyByValue(C_PARAMETER_NAMES_PLOT_SETTINGS, parameterCaption)
-    if (!is.null(parameterName)) {
+    if (!is.null(parameterName) && length(parameterName) == 1 && parameterName %in% fieldNames) {
         return(parameterName)
     }
 
-    fieldNames <- obj$.getVisibleFieldNames()
     for (parameterName in fieldNames) {
         if (identical(.getParameterCaption(parameterName, obj), parameterCaption)) {
             return(parameterName)
@@ -1109,7 +1203,14 @@ getParameterName <- function(obj, parameterCaption) {
         }
     }
 
-    return("unknown")
+    if (!is.null(obj[[".design"]])) {
+        result <- getParameterName(obj$.design, parameterCaption)
+        if (!is.na(result)) {
+            return(paste0(".design$", result))
+        }
+    }
+
+    return(NA_character_)
 }
 
 .removeLastEntryFromArray <- function(x) {
@@ -1172,6 +1273,7 @@ getParameterName <- function(obj, parameterCaption) {
 }
 
 #' @examples
+#' \dontrun{
 #' or1 <- list(
 #'     and1 = FALSE,
 #'     and2 = TRUE,
@@ -1194,6 +1296,7 @@ getParameterName <- function(obj, parameterCaption) {
 #'         )
 #'     )
 #' )
+#' }
 #'
 #' @noRd
 #'
@@ -1385,14 +1488,20 @@ getParameterName <- function(obj, parameterCaption) {
             xCall <- deparse(fCall$x)
             return(identical(xCall[1], ".") || grepl("^summary\\(", xCall[1]))
         },
-        error = function(e) {
-            return(FALSE)
-        }
+        error = function(e) {}
     )
+    return(FALSE)
 }
 
-.isMarkdownEnabled <- function() {
-    return(!is.null(knitr::current_input()))
+.isMarkdownEnabled <- function(type = c("all", "print", "summary", "plot")) {
+    type <- match.arg(type)
+    if (!as.logical(getOption(paste0("rpact.auto.markdown.", type), TRUE))) {
+        return(FALSE)
+    }
+
+    return(!is.null(knitr::current_input()) ||
+        knitr::is_html_output() ||
+        knitr::is_latex_output())
 }
 
 .isRMarkdownEnabled <- function() {
@@ -1488,7 +1597,367 @@ getParameterName <- function(obj, parameterCaption) {
 }
 
 .addDeprecatedFieldValues <- function(parameterSet, fieldName, fieldValues) {
+    if (!fieldName %in% names(parameterSet)) {
+        stop(
+            C_EXCEPTION_TYPE_RUNTIME_ISSUE,
+            "'", .getClassName(parameterSet), "' does not contain a field with name '", fieldName, "'"
+        )
+    }
+    
     parameterSet[[fieldName]] <- fieldValues
     parameterSet$.setParameterType(fieldName, C_PARAM_NOT_APPLICABLE)
     parameterSet$.deprecatedFieldNames <- unique(c(parameterSet$.deprecatedFieldNames, fieldName))
 }
+
+.getPipeOperatorQueue <- function(x) {
+    queue <- attr(x, "queue")
+    if (is.null(queue)) {
+        queue <- list()
+    }
+    if (!is.null(x[["object"]])) {
+        objectQueue <- attr(x$object, "queue")
+        if (!is.null(objectQueue)) {
+            queue <- c(queue, objectQueue)
+        }
+    }
+    return(queue)
+}
+
+.addObjectToPipeOperatorQueue <- function(x) {
+    if (inherits(x, "SummaryFactory")) {
+        x <- x$object
+    }
+
+    queue <- .getPipeOperatorQueue(x)
+    queue[[length(queue) + 1]] <- x
+    attr(x, "markdown") <- TRUE
+    attr(x, "queue") <- queue
+    return(x)
+}
+
+.resetPipeOperatorQueue <- function(x) {
+    for (attrName in c("queue", "printObject", "printObjectSeparator", "markdown")) {
+        tryCatch(
+            {
+                if (inherits(x, "SummaryFactory")) {
+                    attr(x$object, attrName) <- NULL
+                } else {
+                    attr(x, attrName) <- NULL
+                }
+            },
+            error = function(e) {
+                message("Failed to reset pipe operator queue attribute ", sQuote(attrName), ": ", e$message)
+            }
+        )
+    }
+    return(x)
+}
+
+.getMarkdownPlotPrintSeparator <- function() {
+    return(getOption("rpact.markdown.plot.print.separator", C_MARKDOWN_PLOT_PRINT_SEPARATOR))
+}
+
+.getCriticalValues <- function(design, indices = NULL) {
+    if (!is.null(indices)) {
+        return(design$criticalValues[indices])
+    }
+
+    return(design$criticalValues)
+}
+
+.applyDirectionOfAlternative <- function(value,
+        directionUpper,
+        ...,
+        type = c(
+            "oneMinusValue",
+            "valueMinusOne",
+            "negateIfUpper",
+            "negateIfLower",
+            "minMax",
+            "maxMin"
+        ),
+        phase = c("unknown", "design", "planning", "analysis"),
+        syncLength = FALSE) {
+    type <- match.arg(type)
+    phase <- match.arg(phase)
+
+    if (phase == "design") {
+        return(value) # deactivate for current release
+    }
+
+    if (is.null(value) || length(value) == 0 || all(is.na(value))) {
+        return(value)
+    }
+
+    if (syncLength && length(directionUpper) > 1 && length(directionUpper) > length(value)) {
+        directionUpper <- directionUpper[1:length(value)]
+    }
+
+    if (length(directionUpper) > 1 && length(value) != length(directionUpper)) {
+        stop(
+            C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'value' (", .arrayToString(value), ") and ",
+            "'directionUpper' (", .arrayToString(directionUpper), ") must have the same length"
+        )
+    }
+
+    if (length(value) <= 1 || length(directionUpper) == 1) {
+        return(.applyDirectionOfAlternativeSingle(
+            value = value,
+            directionUpper = directionUpper,
+            type = type
+        ))
+    }
+
+    values <- c()
+    for (i in 1:length(value)) {
+        values <- c(
+            values,
+            .applyDirectionOfAlternativeSingle(
+                value = value[i],
+                directionUpper = ifelse(length(directionUpper) == 1, directionUpper, directionUpper[i]),
+                type = type
+            )
+        )
+    }
+    return(values)
+}
+
+.applyDirectionOfAlternativeSingle <- function(...,
+        value,
+        directionUpper,
+        type = c(
+            "oneMinusValue",
+            "valueMinusOne",
+            "negateIfUpper",
+            "negateIfLower",
+            "minMax",
+            "maxMin"
+        )) {
+    type <- match.arg(type)
+    if (is.null(value) || length(value) == 0 || all(is.na(value))) {
+        return(value)
+    }
+
+    if (is.na(directionUpper) || isTRUE(directionUpper)) {
+        if (type == "oneMinusValue") {
+            return(1 - value)
+        }
+        if (type == "valueMinusOne") {
+            return(value - 1)
+        }
+        if (type == "negateIfLower") {
+            return(value)
+        }
+        if (type == "negateIfUpper") {
+            if (is.logical(value)) {
+                return(!value)
+            }
+
+            return(-value)
+        }
+        if (type == "minMax") {
+            return(min(value, na.rm = TRUE))
+        }
+        if (type == "maxMin") {
+            return(max(value, na.rm = TRUE))
+        }
+    }
+
+    if (type == "negateIfLower") {
+        if (is.logical(value)) {
+            return(!value)
+        }
+
+        return(-value)
+    }
+    if (type == "negateIfUpper") {
+        return(value)
+    }
+    if (type == "minMax") {
+        return(max(value, na.rm = TRUE))
+    }
+    if (type == "maxMin") {
+        return(min(value, na.rm = TRUE))
+    }
+
+    return(value)
+}
+
+#'
+#' @note This is only needed such that we can mock the function in the tests.
+#'
+#' @keywords internal
+#'
+#' @noRd
+#'
+.isPackageNamespaceLoaded <- function(package, ..., quietly = FALSE) {
+    base::requireNamespace(package, quietly = quietly, ...)
+}
+
+#'
+#' @title
+#' Save Options
+#'
+#' @description
+#' Saves the current `rpact` options to a configuration file.
+#'
+#' @details
+#' This function attempts to save the current `rpact` options to a configuration file
+#' located in the user's configuration directory. If the `rappdirs` package is not installed,
+#' the function will not perform any action. The options are saved in a YAML file.
+#'
+#' @return
+#' Returns `TRUE` if the options were successfully saved, `FALSE` otherwise.
+#'
+#' @examples
+#' \dontrun{
+#' saveOptions()
+#' }
+#'
+#' @export
+#'
+#' @keywords internal
+#'
+saveOptions <- function() {
+    tryCatch(
+        {
+            if (!.isPackageNamespaceLoaded("rappdirs", quietly = TRUE)) {
+                return(invisible(FALSE))
+            }
+
+            pkgConfigDir <- rappdirs::user_config_dir("rpact")
+            if (!dir.exists(pkgConfigDir)) {
+                dir.create(pkgConfigDir, recursive = TRUE, showWarnings = FALSE)
+            }
+            if (!dir.exists(pkgConfigDir)) {
+                return(invisible(FALSE))
+            }
+
+            optionNames <- make.names(names(base::options()))
+            optionNames <- optionNames[grepl("^rpact\\.", optionNames)]
+            optionFileContent <- character()
+            for (optionName in optionNames) {
+                optionValue <- getOption(optionName)
+                if (!is.null(optionValue)) {
+                    optionFileContent <- c(optionFileContent, paste0(optionName, ": ", optionValue))
+                }
+            }
+            optionsFile <- file.path(pkgConfigDir, "options.yml")
+            cat(optionFileContent, file = optionsFile, sep = "\n")
+            return(invisible(file.exists(optionsFile)))
+        },
+        error = function(e) {
+            warning("Failed to save rpact options: ", e$message, call. = FALSE)
+            return(invisible(FALSE))
+        }
+    )
+}
+
+#'
+#' @title
+#' Reset Options
+#'
+#' @description
+#' Resets the `rpact` options to their default values.
+#'
+#' @param persist A logical value indicating whether the reset options should be saved persistently.
+#'        If `TRUE`, the options will be saved after resetting. Default is `TRUE`.
+#'
+#' @details
+#' This function resets all `rpact` options to their default values. If the `persist` parameter is set to `TRUE`,
+#' the reset options will be saved to a configuration file.
+#'
+#' @return
+#' Returns `TRUE` if the options were successfully reset, `FALSE` otherwise.
+#'
+#' @examples
+#' \dontrun{
+#' resetOptions()
+#' resetOptions(persist = FALSE)
+#' }
+#'
+#' @export
+#'
+#' @keywords internal
+#'
+resetOptions <- function(persist = TRUE) {
+    .assertIsSingleLogical(persist, "persist")
+    tryCatch(
+        {
+            optionNames <- make.names(names(base::options()))
+            optionNames <- optionNames[grepl("^rpact\\.", optionNames)]
+            if (length(optionNames) == 0) {
+                return(invisible(TRUE))
+            }
+
+            for (optionName in optionNames) {
+                eval(parse(text = paste0('base::options("', optionName, '" = NULL)')))
+            }
+            if (persist) {
+                saveOptions()
+            }
+            return(invisible(TRUE))
+        },
+        error = function(e) {
+            warning("Failed to reset rpact options: ", e$message, call. = FALSE)
+            return(invisible(FALSE))
+        }
+    )
+}
+
+.loadOptions <- function() {
+    tryCatch(
+        {
+            if (!.isPackageNamespaceLoaded("rappdirs", quietly = TRUE)) {
+                packageStartupMessage(
+                    "Package \"rappdirs\" is needed for saving and loading rpact options. ",
+                    "Please install using, e.g., install.packages(\"rappdirs\")"
+                )
+                return(invisible(FALSE))
+            }
+
+            pkgConfigDir <- rappdirs::user_config_dir("rpact")
+            if (!dir.exists(pkgConfigDir)) {
+                return(invisible(FALSE))
+            }
+
+            pkgConfigFile <- file.path(pkgConfigDir, "options.yml")
+            if (!file.exists(pkgConfigFile)) {
+                return(invisible(FALSE))
+            }
+
+            optionFileContent <- readLines(pkgConfigFile)
+            if (length(optionFileContent) == 0) {
+                return(invisible(TRUE))
+            }
+
+            optionsList <- list()
+            for (line in optionFileContent) {
+                optionName <- sub(":.*", "", line)
+                if (is.null(optionName) || length(optionName) != 1 || nchar(trimws(optionName)) == 0) {
+                    next
+                }
+
+                optionValue <- sub(".*: ", "", line)
+                if (is.null(optionValue) || length(optionValue) != 1 || nchar(trimws(optionValue)) == 0) {
+                    next
+                }
+
+                optionsList[[optionName]] <- optionValue
+            }
+
+            if (length(optionsList) == 0) {
+                return(invisible(TRUE))
+            }
+
+            base::options(optionsList)
+            return(invisible(TRUE))
+        },
+        error = function(e) {
+            packageStartupMessage("Failed to load and set rpact options: ", e$message)
+            return(invisible(FALSE))
+        }
+    )
+}
+
+
