@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7742 $
-## |  Last changed: $Date: 2024-03-22 13:46:29 +0100 (Fr, 22 Mrz 2024) $
+## |  File version: $Revision: 8612 $
+## |  Last changed: $Date: 2025-03-14 06:39:43 +0100 (Fr, 14 Mrz 2025) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -78,6 +78,8 @@ NULL
             designPlan$cumulativeEventsPerStage <- matrix(designPlan$eventsFixed, nrow = 1)
         }
         boundaries <- .getEffectScaleBoundaryDataSurvival(designPlan)
+    } else if (.isTrialDesignPlanCountData(designPlan)) {
+        boundaries <- .getEffectScaleBoundaryDataCounts(designPlan)
     }
 
     if (designPlan$.design$sided == 1) {
@@ -95,7 +97,7 @@ NULL
         designPlan$.setParameterType("criticalValuesEffectScaleLower", C_PARAM_GENERATED)
     }
 
-    if (!.isTrialDesignFisher(design) && any(design$futilityBounds > C_FUTILITY_BOUNDS_DEFAULT)) {
+    if (.hasApplicableFutilityBounds(design)) {
         if (design$sided == 1) {
             designPlan$futilityBoundsEffectScale <- round(boundaries$futilityBoundsEffectScaleUpper, 8)
             designPlan$.setParameterType("futilityBoundsEffectScale", C_PARAM_GENERATED)
@@ -139,6 +141,7 @@ NULL
             beta = designPlan$getBeta(),
             sided = designPlan$getSided(),
             normalApproximation = designPlan$normalApproximation,
+            conservative = designPlan$conservative,
             riskRatio = designPlan$riskRatio,
             thetaH0 = designPlan$thetaH0,
             pi1 = designPlan$pi1,
@@ -241,7 +244,7 @@ NULL
             designPlan$.setParameterType("earlyStop", C_PARAM_GENERATED)
         }
         if (!is.null(sampleSizeSequential$futilityPerStage) &&
-                any(designPlan$.design$futilityBounds != C_FUTILITY_BOUNDS_DEFAULT)) {
+                any(designPlan$.design$futilityBounds != C_FUTILITY_BOUNDS_DEFAULT, na.rm = TRUE)) {
             designPlan$futilityPerStage <- matrix(sampleSizeSequential$futilityPerStage,
                 nrow = designPlan$.design$kMax - 1
             )
@@ -385,7 +388,7 @@ NULL
             accrualTime[1:(length(accrualTime) - 1)]
     }
     densityVector <- accrualIntensity / sum(densityIntervals * accrualIntensity)
-    for (l in 1:length(densityVector)) {
+    for (l in seq_len(length(densityVector))) {
         if (timeValue <= accrualTime[l]) {
             if (l == 1) {
                 return(timeValue * densityVector[l] * maxNumberOfSubjects)
