@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8225 $
-## |  Last changed: $Date: 2024-09-18 09:38:40 +0200 (Mi, 18 Sep 2024) $
+## |  File version: $Revision: 8712 $
+## |  Last changed: $Date: 2025-05-15 09:57:14 +0200 (Do, 15 Mai 2025) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -286,8 +286,10 @@ getSimulationSurvival <- function(design = NULL, ...,
         design <- .resetPipeOperatorQueue(design)
     }
 
-    directionUpper <- .assertIsValidDirectionUpper(directionUpper, 
-        design, objectType = "power", userFunctionCallEnabled = TRUE)
+    directionUpper <- .assertIsValidDirectionUpper(directionUpper,
+        design,
+        objectType = "power", userFunctionCallEnabled = TRUE
+    )
     .assertIsSingleNumber(thetaH0, "thetaH0")
     .assertIsInOpenInterval(thetaH0, "thetaH0", 0, NULL, naAllowed = TRUE)
     .assertIsNumericVector(minNumberOfEventsPerStage, "minNumberOfEventsPerStage", naAllowed = TRUE)
@@ -315,28 +317,24 @@ getSimulationSurvival <- function(design = NULL, ...,
     if (!is.na(dropoutTime) && dropoutTime <= 0) {
         stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'dropoutTime' (", dropoutTime, ") must be > 0", call. = FALSE)
     }
-
     if (dropoutRate1 < 0 || dropoutRate1 >= 1) {
         stop(
             C_EXCEPTION_TYPE_ARGUMENT_OUT_OF_BOUNDS,
             "'dropoutRate1' (", dropoutRate1, ") is out of bounds [0; 1)"
         )
     }
-
     if (dropoutRate2 < 0 || dropoutRate2 >= 1) {
         stop(
             C_EXCEPTION_TYPE_ARGUMENT_OUT_OF_BOUNDS,
             "'dropoutRate2' (", dropoutRate2, ") is out of bounds [0; 1)"
         )
     }
-
     if (design$sided == 2) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
             "Only one-sided case is implemented for the survival simulation design"
         )
     }
-
     if (!all(is.na(lambda2)) && !all(is.na(lambda1)) &&
             length(lambda2) != length(lambda1) && length(lambda2) > 1) {
         stop(
@@ -344,7 +342,6 @@ getSimulationSurvival <- function(design = NULL, ...,
             ") must be equal to length of 'lambda1' (", length(lambda1), ")"
         )
     }
-
     if (all(is.na(lambda2)) && !all(is.na(lambda1))) {
         warning("'lambda1' (", .arrayToString(lambda1), ") will be ignored ",
             "because 'lambda2' (", .arrayToString(lambda2), ") is undefined",
@@ -352,7 +349,6 @@ getSimulationSurvival <- function(design = NULL, ...,
         )
         lambda1 <- NA_real_
     }
-
     if (!all(is.na(lambda2)) && is.list(piecewiseSurvivalTime)) {
         stop(
             C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
@@ -360,7 +356,6 @@ getSimulationSurvival <- function(design = NULL, ...,
             "because 'lambda2' (", .arrayToString(lambda2), ") is defined separately"
         )
     }
-
     thetaH1 <- .ignoreParameterIfNotUsed(
         "thetaH1", thetaH1, design$kMax > 1,
         "design is fixed ('kMax' = 1)", "Assumed effect"
@@ -470,9 +465,17 @@ getSimulationSurvival <- function(design = NULL, ...,
 
     pwsTimeObject <- getPiecewiseSurvivalTime(
         piecewiseSurvivalTime = piecewiseSurvivalTime,
-        lambda2 = lambda2, lambda1 = lambda1, median1 = median1, median2 = median2,
-        hazardRatio = hazardRatio, pi1 = pi1, pi2 = pi2, eventTime = eventTime, kappa = kappa,
-        delayedResponseAllowed = TRUE, .pi1Default = C_PI_1_DEFAULT
+        lambda2 = lambda2,
+        lambda1 = lambda1,
+        median1 = median1,
+        median2 = median2,
+        hazardRatio = hazardRatio,
+        pi1 = pi1,
+        pi2 = pi2,
+        eventTime = eventTime,
+        kappa = kappa,
+        delayedResponseAllowed = TRUE,
+        .pi1Default = C_PI_1_DEFAULT
     )
 
     simulationResults$.piecewiseSurvivalTime <- pwsTimeObject
@@ -589,7 +592,7 @@ getSimulationSurvival <- function(design = NULL, ...,
     .setValueAndParameterType(simulationResults, "dropoutTime", dropoutTime, C_DROP_OUT_TIME_DEFAULT)
     .setValueAndParameterType(simulationResults, "thetaH0", thetaH0, C_THETA_H0_SURVIVAL_DEFAULT)
 
-    allocationFraction <- getFraction(allocation1 / allocation2)
+    allocationFraction <- .getFraction(allocation1 / allocation2)
     if (allocationFraction[1] != allocation1 || allocationFraction[2] != allocation2) {
         warning(sprintf(
             "allocation1 = %s and allocation2 = %s was replaced by allocation1 = %s and allocation2 = %s",
@@ -598,6 +601,7 @@ getSimulationSurvival <- function(design = NULL, ...,
         allocation1 <- allocationFraction[1]
         allocation2 <- allocationFraction[2]
     }
+    .warnInCaseOfExtremeAllocationRatios(allocation1, allocation2)
 
     .setValueAndParameterType(simulationResults, "allocation1", allocation1, C_ALLOCATION_1_DEFAULT)
     .setValueAndParameterType(simulationResults, "allocation2", allocation2, C_ALLOCATION_2_DEFAULT)
@@ -626,50 +630,26 @@ getSimulationSurvival <- function(design = NULL, ...,
 
     phi <- -c(log(1 - dropoutRate1), log(1 - dropoutRate2)) / dropoutTime
 
-    densityIntervals <- accrualTime
-    if (length(accrualTime) > 1) {
-        densityIntervals[2:length(accrualTime)] <-
-            accrualTime[2:length(accrualTime)] - accrualTime[1:(length(accrualTime) - 1)]
-    }
-    densityVector <- accrualSetup$accrualIntensity / sum(densityIntervals * accrualSetup$accrualIntensity)
+    recruitmentTimes <- .generateRecruitmentTimes(
+        allocationRatioPlanned,
+        accrualTime,
+        accrualSetup$accrualIntensity
+    )$recruit
 
-    intensityReplications <- round(densityVector * densityIntervals * accrualSetup$maxNumberOfSubjects)
+    recruitmentTimes <- recruitmentTimes[1:accrualSetup$maxNumberOfSubjects]
 
-    if (all(intensityReplications > 0)) {
-        accrualTimeValue <- cumsum(rep(
-            1 / (densityVector * accrualSetup$maxNumberOfSubjects), intensityReplications
-        ))
-    } else {
-        accrualTimeValue <- cumsum(rep(
-            1 / (densityVector[1] * accrualSetup$maxNumberOfSubjects),
-            intensityReplications[1]
-        ))
-        if (length(accrualIntensity) > 1 && length(intensityReplications) > 1) {
-            for (i in 2:min(length(accrualIntensity), length(intensityReplications))) {
-                if (intensityReplications[i] > 0) {
-                    accrualTimeValue <- c(
-                        accrualTimeValue,
-                        accrualTime[i - 1] +
-                            cumsum(rep(
-                                1 / (densityVector[i] * accrualSetup$maxNumberOfSubjects),
-                                intensityReplications[i]
-                            ))
-                    )
-                }
-            }
+    # to force last value to be last accrualTime
+    recruitmentTimes[length(recruitmentTimes)] <- accrualTime[length(accrualTime)]
+
+    treatments <- c()
+    while (length(treatments) < accrualSetup$maxNumberOfSubjects) {
+        if (allocation1 > allocation2) {
+            treatments <- c(treatments, rep(c(1, 2), allocation2), rep(1, allocation1 - allocation2))
+        } else {
+            treatments <- c(treatments, rep(c(1, 2), allocation1), rep(2, allocation2 - allocation1))
         }
     }
-
-    accrualTimeValue <- accrualTimeValue[1:accrualSetup$maxNumberOfSubjects]
-
-    # to avoid last value to be NA_real_
-    accrualTimeValue[is.na(accrualTimeValue)] <- accrualTime[length(accrualTime)]
-
-    treatmentGroup <- rep(
-        c(rep(1, allocation1), rep(2, allocation2)),
-        ceiling(accrualSetup$maxNumberOfSubjects /
-            (allocation1 + allocation2))
-    )[1:accrualSetup$maxNumberOfSubjects]
+    treatments <- treatments[1:accrualSetup$maxNumberOfSubjects]
 
     if (.isTrialDesignFisher(design)) {
         alpha0Vec <- design$alpha0Vec
@@ -721,8 +701,8 @@ getSimulationSurvival <- function(design = NULL, ...,
         maxNumberOfEventsPerStage      = maxNumberOfEventsPerStage,
         directionUpper                 = directionUpper,
         allocationRatioPlanned         = allocationRatioPlanned,
-        accrualTime                    = accrualTimeValue,
-        treatmentGroup                 = treatmentGroup,
+        accrualTime                    = recruitmentTimes,
+        treatmentGroup                 = treatments,
         thetaH0                        = thetaH0,
         futilityBounds                 = futilityBounds,
         alpha0Vec                      = alpha0Vec,
@@ -910,7 +890,7 @@ getSimulationSurvival <- function(design = NULL, ...,
             pi2 = numeric(0),
             subjectId = numeric(0),
             accrualTime = numeric(0),
-            treatmentGroup = numeric(0),
+            treatments = numeric(0),
             survivalTime = numeric(0),
             dropoutTime = numeric(0),
             observationTime = numeric(0),
