@@ -13,34 +13,45 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7910 $
-## |  Last changed: $Date: 2024-05-22 10:02:23 +0200 (Mi, 22 Mai 2024) $
-## |  Last changed by: $Author: pahlke $
+## |  File version: $Revision: 8738 $
+## |  Last changed: $Date: 2025-06-04 13:12:30 +0200 (Mi, 04 Jun 2025) $
+## |  Last changed by: $Author: wassmer $
 ## |
 
 #' @include f_simulation_enrichment.R
 NULL
 
-.getSimulationMeansEnrichmentStageSubjects <- function(..., stage,
-        conditionalPower,
-        conditionalCriticalValue,
-        plannedSubjects,
-        allocationRatioPlanned,
-        selectedPopulations,
-        thetaH1,
-        overallEffects,
-        stDevH1,
-        minNumberOfSubjectsPerStage,
-        maxNumberOfSubjectsPerStage) {
+.getSimulationMeansEnrichmentStageSubjects <- function(
+    ...,
+    stage,
+    conditionalPower,
+    conditionalCriticalValue,
+    plannedSubjects,
+    allocationRatioPlanned,
+    selectedPopulations,
+    thetaH1,
+    overallEffects,
+    stDevH1,
+    minNumberOfSubjectsPerStage,
+    maxNumberOfSubjectsPerStage
+) {
     stage <- stage - 1 # to be consistent with non-enrichment situation
     gMax <- nrow(overallEffects)
 
     if (!is.na(conditionalPower)) {
         if (any(selectedPopulations[1:gMax, stage + 1], na.rm = TRUE)) {
             if (is.na(thetaH1)) {
-                thetaStandardized <- max(min(overallEffects[
-                    selectedPopulations[1:gMax, stage + 1], stage
-                ] / stDevH1, na.rm = TRUE), 1e-07)
+                thetaStandardized <- max(
+                    min(
+                        overallEffects[
+                            selectedPopulations[1:gMax, stage + 1],
+                            stage
+                        ] /
+                            stDevH1,
+                        na.rm = TRUE
+                    ),
+                    1e-07
+                )
             } else {
                 max(thetaStandardized <- thetaH1 / stDevH1, 1e-07)
             }
@@ -48,9 +59,14 @@ NULL
             if (conditionalCriticalValue[stage] > 8) {
                 newSubjects <- maxNumberOfSubjectsPerStage[stage + 1]
             } else {
-                newSubjects <- (1 + allocationRatioPlanned[stage])^2 / allocationRatioPlanned[stage] *
-                    (max(0, conditionalCriticalValue[stage] +
-                        .getQNorm(conditionalPower)))^2 / thetaStandardized^2
+                newSubjects <- (1 + allocationRatioPlanned[stage])^2 /
+                    allocationRatioPlanned[stage] *
+                    (max(
+                        0,
+                        conditionalCriticalValue[stage] +
+                            .getQNorm(conditionalPower)
+                    ))^2 /
+                    thetaStandardized^2
                 newSubjects <- min(
                     max(minNumberOfSubjectsPerStage[stage + 1], newSubjects),
                     maxNumberOfSubjectsPerStage[stage + 1]
@@ -66,29 +82,31 @@ NULL
     return(newSubjects)
 }
 
-.getSimulatedStageMeansEnrichment <- function(...,
-        design,
-        subsets,
-        prevalences,
-        effects,
-        stDevs,
-        stratifiedAnalysis,
-        plannedSubjects,
-        typeOfSelection,
-        effectMeasure,
-        adaptations,
-        epsilonValue,
-        rValue,
-        threshold,
-        allocationRatioPlanned,
-        minNumberOfSubjectsPerStage,
-        maxNumberOfSubjectsPerStage,
-        conditionalPower,
-        thetaH1,
-        stDevH1,
-        calcSubjectsFunction,
-        calcSubjectsFunctionIsUserDefined,
-        selectPopulationsFunction) {
+.getSimulatedStageMeansEnrichment <- function(
+    ...,
+    design,
+    subsets,
+    prevalences,
+    effects,
+    stDevs,
+    stratifiedAnalysis,
+    plannedSubjects,
+    typeOfSelection,
+    effectMeasure,
+    adaptations,
+    epsilonValue,
+    rValue,
+    threshold,
+    allocationRatioPlanned,
+    minNumberOfSubjectsPerStage,
+    maxNumberOfSubjectsPerStage,
+    conditionalPower,
+    thetaH1,
+    stDevH1,
+    calcSubjectsFunction,
+    calcSubjectsFunctionIsUserDefined,
+    selectPopulationsFunction
+) {
     kMax <- length(plannedSubjects)
     pMax <- length(effects)
     gMax <- log(length(effects), 2) + 1
@@ -115,20 +133,17 @@ NULL
         weights <- .getWeightsInverseNormal(design)
     }
 
-
-    for (k in 1:kMax) {
+    for (k in seq_len(kMax)) {
         const <- allocationRatioPlanned[k] / (1 + allocationRatioPlanned[k])^2
 
-        selectedSubsets[, k] <- .createSelectedSubsets(k, selectedPopulations)
+        selectedSubsets[, k] <- .createSelectedSubsets(selectedPopulations[, k])
 
         if (k == 1) {
-            # subjectsPerStage[, k] <- stats::rmultinom(1, plannedSubjects[k], prevalences)
             subjectsPerStage[, k] <- plannedSubjects[k] * prevalences
         } else {
             prevSelected <- prevalences / sum(prevalences[selectedSubsets[, k]])
             prevSelected[!selectedSubsets[, k]] <- 0
             if (sum(prevSelected, na.rm = TRUE) > 0) {
-                # subjectsPerStage[, k] <- stats::rmultinom(1, plannedSubjects[k] - plannedSubjects[k - 1], prevSelected)
                 subjectsPerStage[, k] <- (plannedSubjects[k] - plannedSubjects[k - 1]) * prevSelected
             } else {
                 break
@@ -136,8 +151,12 @@ NULL
         }
 
         selsubs <- !is.na(subjectsPerStage[, k]) & subjectsPerStage[, k] > 0
-        simEffects[selsubs, k] <- stats::rnorm(rep(1, sum(selsubs)), effects[selsubs], stDevs[selsubs] /
-            sqrt(subjectsPerStage[selsubs, k] * const))
+        simEffects[selsubs, k] <- stats::rnorm(
+            rep(1, sum(selsubs)),
+            effects[selsubs],
+            stDevs[selsubs] /
+                sqrt(subjectsPerStage[selsubs, k] * const)
+        )
 
         if (gMax == 1) {
             testStatistics[1, k] <- simEffects[1, k] / stDevs[1] * sqrt(subjectsPerStage[1, k] * const)
@@ -155,95 +174,136 @@ NULL
             overallTestStatistics[1, k] <- overallEffects[1, k] /
                 (stDevs[1] / sqrt(sum(subjectsPerStage[1, 1:k]) * const))
             # Full population
-            testStatistics[2, k] <- sum(subjectsPerStage[1:2, k] * simEffects[1:2, k], na.rm = TRUE) * sqrt(const) /
+            testStatistics[2, k] <- sum(subjectsPerStage[1:2, k] * simEffects[1:2, k], na.rm = TRUE) *
+                sqrt(const) /
                 sqrt(sum(subjectsPerStage[1:2, k] * stDevs[1:2]^2, na.rm = TRUE))
             populationSubjectsPerStage[2, k] <- sum(subjectsPerStage[1:2, k], na.rm = TRUE)
 
             overallEffects[2, k] <- sum(subjectsPerStage[1:2, 1:k] * simEffects[1:2, 1:k], na.rm = TRUE) /
                 sum(subjectsPerStage[1:2, 1:k], na.rm = TRUE)
-            sd <- sqrt(sum(subjectsPerStage[1:2, 1:k] * stDevs[1:2]^2, na.rm = TRUE) /
-                sum(subjectsPerStage[1:2, 1:k], na.rm = TRUE))
+            sd <- sqrt(
+                sum(subjectsPerStage[1:2, 1:k] * stDevs[1:2]^2, na.rm = TRUE) /
+                    sum(subjectsPerStage[1:2, 1:k], na.rm = TRUE)
+            )
             overallTestStatistics[2, k] <- overallEffects[2, k] /
-                sd * sqrt(sum(subjectsPerStage[1:2, 1:k], na.rm = TRUE) * const)
+                sd *
+                sqrt(sum(subjectsPerStage[1:2, 1:k], na.rm = TRUE) * const)
         } else if (gMax == 3) {
             # Population S1
-            testStatistics[1, k] <- sum(subjectsPerStage[c(1, 3), k] * simEffects[c(1, 3), k], na.rm = TRUE) * sqrt(const) /
+            testStatistics[1, k] <- sum(subjectsPerStage[c(1, 3), k] * simEffects[c(1, 3), k], na.rm = TRUE) *
+                sqrt(const) /
                 sqrt(sum(subjectsPerStage[c(1, 3), k] * stDevs[c(1, 3)]^2, na.rm = TRUE))
             populationSubjectsPerStage[1, k] <- sum(subjectsPerStage[c(1, 3), k], na.rm = TRUE)
             overallEffects[1, k] <-
                 sum(subjectsPerStage[c(1, 3), 1:k] * simEffects[c(1, 3), 1:k], na.rm = TRUE) /
+                sum(subjectsPerStage[c(1, 3), 1:k], na.rm = TRUE)
+            sd <- sqrt(
+                sum(subjectsPerStage[c(1, 3), 1:k] * stDevs[c(1, 3)]^2, na.rm = TRUE) /
                     sum(subjectsPerStage[c(1, 3), 1:k], na.rm = TRUE)
-            sd <- sqrt(sum(subjectsPerStage[c(1, 3), 1:k] * stDevs[c(1, 3)]^2, na.rm = TRUE) /
-                sum(subjectsPerStage[c(1, 3), 1:k], na.rm = TRUE))
+            )
             overallTestStatistics[1, k] <- overallEffects[1, k] /
-                sd * sqrt(sum(subjectsPerStage[c(1, 3), 1:k], na.rm = TRUE) * const)
+                sd *
+                sqrt(sum(subjectsPerStage[c(1, 3), 1:k], na.rm = TRUE) * const)
             # Population S2
-            testStatistics[2, k] <- sum(subjectsPerStage[c(2, 3), k] * simEffects[c(2, 3), k], na.rm = TRUE) * sqrt(const) /
+            testStatistics[2, k] <- sum(subjectsPerStage[c(2, 3), k] * simEffects[c(2, 3), k], na.rm = TRUE) *
+                sqrt(const) /
                 sqrt(sum(subjectsPerStage[c(2, 3), k] * stDevs[c(2, 3)]^2, na.rm = TRUE))
             populationSubjectsPerStage[2, k] <- sum(subjectsPerStage[c(2, 3), k])
             overallEffects[2, k] <-
                 sum(subjectsPerStage[c(2, 3), 1:k] * simEffects[c(2, 3), 1:k], na.rm = TRUE) /
+                sum(subjectsPerStage[c(2, 3), 1:k], na.rm = TRUE)
+            sd <- sqrt(
+                sum(subjectsPerStage[c(2, 3), 1:k] * stDevs[c(2, 3)]^2, na.rm = TRUE) /
                     sum(subjectsPerStage[c(2, 3), 1:k], na.rm = TRUE)
-            sd <- sqrt(sum(subjectsPerStage[c(2, 3), 1:k] * stDevs[c(2, 3)]^2, na.rm = TRUE) /
-                sum(subjectsPerStage[c(2, 3), 1:k], na.rm = TRUE))
+            )
             overallTestStatistics[2, k] <- overallEffects[2, k] /
-                sd * sqrt(sum(subjectsPerStage[c(2, 3), 1:k], na.rm = TRUE) * const)
+                sd *
+                sqrt(sum(subjectsPerStage[c(2, 3), 1:k], na.rm = TRUE) * const)
             # Full population
-            testStatistics[3, k] <- sum(subjectsPerStage[1:4, k] * simEffects[1:4, k], na.rm = TRUE) * sqrt(const) /
+            testStatistics[3, k] <- sum(subjectsPerStage[1:4, k] * simEffects[1:4, k], na.rm = TRUE) *
+                sqrt(const) /
                 sqrt(sum(subjectsPerStage[1:4, k] * stDevs[1:4]^2, na.rm = TRUE))
             populationSubjectsPerStage[3, k] <- sum(subjectsPerStage[1:4, k])
             overallEffects[3, k] <-
                 sum(subjectsPerStage[1:4, 1:k] * simEffects[1:4, 1:k], na.rm = TRUE) /
+                sum(subjectsPerStage[1:4, 1:k], na.rm = TRUE)
+            sd <- sqrt(
+                sum(subjectsPerStage[1:4, 1:k] * stDevs[1:4]^2, na.rm = TRUE) /
                     sum(subjectsPerStage[1:4, 1:k], na.rm = TRUE)
-            sd <- sqrt(sum(subjectsPerStage[1:4, 1:k] * stDevs[1:4]^2, na.rm = TRUE) /
-                sum(subjectsPerStage[1:4, 1:k], na.rm = TRUE))
+            )
             overallTestStatistics[3, k] <- overallEffects[3, k] /
-                sd * sqrt(sum(subjectsPerStage[1:4, 1:k], na.rm = TRUE) * const)
+                sd *
+                sqrt(sum(subjectsPerStage[1:4, 1:k], na.rm = TRUE) * const)
         } else if (gMax == 4) {
             # Population S1
-            testStatistics[1, k] <- sum(subjectsPerStage[c(1, 4, 5, 7), k] * simEffects[c(1, 4, 5, 7), k], na.rm = TRUE) * sqrt(const) /
+            testStatistics[1, k] <- sum(
+                subjectsPerStage[c(1, 4, 5, 7), k] * simEffects[c(1, 4, 5, 7), k],
+                na.rm = TRUE
+            ) *
+                sqrt(const) /
                 sqrt(sum(subjectsPerStage[c(1, 4, 5, 7), k] * stDevs[c(1, 4, 5, 7)]^2, na.rm = TRUE))
             populationSubjectsPerStage[1, k] <- sum(subjectsPerStage[c(1, 4, 5, 7), k], na.rm = TRUE)
             overallEffects[1, k] <-
                 sum(subjectsPerStage[c(1, 4, 5, 7), 1:k] * simEffects[c(1, 4, 5, 7), 1:k], na.rm = TRUE) /
+                sum(subjectsPerStage[c(1, 4, 5, 7), 1:k], na.rm = TRUE)
+            sd <- sqrt(
+                sum(subjectsPerStage[c(1, 4, 5, 7), 1:k] * stDevs[c(1, 4, 5, 7)]^2, na.rm = TRUE) /
                     sum(subjectsPerStage[c(1, 4, 5, 7), 1:k], na.rm = TRUE)
-            sd <- sqrt(sum(subjectsPerStage[c(1, 4, 5, 7), 1:k] * stDevs[c(1, 4, 5, 7)]^2, na.rm = TRUE) /
-                sum(subjectsPerStage[c(1, 4, 5, 7), 1:k], na.rm = TRUE))
+            )
             overallTestStatistics[1, k] <- overallEffects[1, k] /
-                sd * sqrt(sum(subjectsPerStage[c(1, 4, 5, 7), 1:k], na.rm = TRUE) * const)
+                sd *
+                sqrt(sum(subjectsPerStage[c(1, 4, 5, 7), 1:k], na.rm = TRUE) * const)
             # Population S2
-            testStatistics[2, k] <- sum(subjectsPerStage[c(2, 4, 6, 7), k] * simEffects[c(2, 4, 6, 7), k], na.rm = TRUE) * sqrt(const) /
+            testStatistics[2, k] <- sum(
+                subjectsPerStage[c(2, 4, 6, 7), k] * simEffects[c(2, 4, 6, 7), k],
+                na.rm = TRUE
+            ) *
+                sqrt(const) /
                 sqrt(sum(subjectsPerStage[c(2, 4, 6, 7), k] * stDevs[c(2, 4, 6, 7)]^2, na.rm = TRUE))
             populationSubjectsPerStage[2, k] <- sum(subjectsPerStage[c(2, 4, 6, 7), k])
             overallEffects[2, k] <-
                 sum(subjectsPerStage[c(2, 4, 6, 7), 1:k] * simEffects[c(2, 4, 6, 7), 1:k], na.rm = TRUE) /
+                sum(subjectsPerStage[c(2, 4, 6, 7), 1:k], na.rm = TRUE)
+            sd <- sqrt(
+                sum(subjectsPerStage[c(2, 4, 6, 7), 1:k] * stDevs[c(2, 4, 6, 7)]^2, na.rm = TRUE) /
                     sum(subjectsPerStage[c(2, 4, 6, 7), 1:k], na.rm = TRUE)
-            sd <- sqrt(sum(subjectsPerStage[c(2, 4, 6, 7), 1:k] * stDevs[c(2, 4, 6, 7)]^2, na.rm = TRUE) /
-                sum(subjectsPerStage[c(2, 4, 6, 7), 1:k], na.rm = TRUE))
+            )
             overallTestStatistics[2, k] <- overallEffects[2, k] /
-                sd * sqrt(sum(subjectsPerStage[c(2, 4, 6, 7), 1:k], na.rm = TRUE) * const)
+                sd *
+                sqrt(sum(subjectsPerStage[c(2, 4, 6, 7), 1:k], na.rm = TRUE) * const)
             # Population S3
-            testStatistics[3, k] <- sum(subjectsPerStage[c(3, 5, 6, 7), k] * simEffects[c(3, 5, 6, 7), k], na.rm = TRUE) * sqrt(const) /
+            testStatistics[3, k] <- sum(
+                subjectsPerStage[c(3, 5, 6, 7), k] * simEffects[c(3, 5, 6, 7), k],
+                na.rm = TRUE
+            ) *
+                sqrt(const) /
                 sqrt(sum(subjectsPerStage[c(3, 5, 6, 7), k] * stDevs[c(3, 5, 6, 7)]^2, na.rm = TRUE))
             populationSubjectsPerStage[3, k] <- sum(subjectsPerStage[c(3, 5, 6, 7), k])
             overallEffects[3, k] <-
                 sum(subjectsPerStage[c(3, 5, 6, 7), 1:k] * simEffects[c(3, 5, 6, 7), 1:k], na.rm = TRUE) /
+                sum(subjectsPerStage[c(3, 5, 6, 7), 1:k], na.rm = TRUE)
+            sd <- sqrt(
+                sum(subjectsPerStage[c(3, 5, 6, 7), 1:k] * stDevs[c(3, 5, 6, 7)]^2, na.rm = TRUE) /
                     sum(subjectsPerStage[c(3, 5, 6, 7), 1:k], na.rm = TRUE)
-            sd <- sqrt(sum(subjectsPerStage[c(3, 5, 6, 7), 1:k] * stDevs[c(3, 5, 6, 7)]^2, na.rm = TRUE) /
-                sum(subjectsPerStage[c(3, 5, 6, 7), 1:k], na.rm = TRUE))
+            )
             overallTestStatistics[3, k] <- overallEffects[3, k] /
-                sd * sqrt(sum(subjectsPerStage[c(3, 5, 6, 7), 1:k], na.rm = TRUE) * const)
+                sd *
+                sqrt(sum(subjectsPerStage[c(3, 5, 6, 7), 1:k], na.rm = TRUE) * const)
             # Full population
-            testStatistics[4, k] <- sum(subjectsPerStage[1:8, k] * simEffects[1:8, k], na.rm = TRUE) * sqrt(const) /
+            testStatistics[4, k] <- sum(subjectsPerStage[1:8, k] * simEffects[1:8, k], na.rm = TRUE) *
+                sqrt(const) /
                 sqrt(sum(subjectsPerStage[1:8, k] * stDevs[1:8]^2, na.rm = TRUE))
             populationSubjectsPerStage[4, k] <- sum(subjectsPerStage[1:8, k])
             overallEffects[4, k] <-
                 sum(subjectsPerStage[1:8, 1:k] * simEffects[1:8, 1:k], na.rm = TRUE) /
+                sum(subjectsPerStage[1:8, 1:k], na.rm = TRUE)
+            sd <- sqrt(
+                sum(subjectsPerStage[1:8, 1:k] * stDevs[1:8]^2, na.rm = TRUE) /
                     sum(subjectsPerStage[1:8, 1:k], na.rm = TRUE)
-            sd <- sqrt(sum(subjectsPerStage[1:8, 1:k] * stDevs[1:8]^2, na.rm = TRUE) /
-                sum(subjectsPerStage[1:8, 1:k], na.rm = TRUE))
+            )
             overallTestStatistics[4, k] <- overallEffects[4, k] /
-                sd * sqrt(sum(subjectsPerStage[1:8, 1:k], na.rm = TRUE) * const)
+                sd *
+                sqrt(sum(subjectsPerStage[1:8, 1:k], na.rm = TRUE) * const)
         }
 
         testStatistics[!selectedPopulations[, k], k] <- NA_real_
@@ -252,21 +312,28 @@ NULL
 
         separatePValues[, k] <- 1 - stats::pnorm(testStatistics[, k])
 
+        criticalValues <- .getCriticalValues(design)
         if (k < kMax) {
             if (colSums(selectedPopulations)[k] == 0) {
                 break
             }
 
             # Bonferroni adjustment
-            adjustedPValues[k] <- min(min(separatePValues[, k], na.rm = TRUE) *
-                colSums(selectedPopulations)[k], 1 - 1e-07)
+            adjustedPValues[k] <- min(
+                min(separatePValues[, k], na.rm = TRUE) *
+                    colSums(selectedPopulations)[k],
+                1 - 1e-07
+            )
 
             # conditional critical value to reject the null hypotheses at the next stage of the trial
             if (.isTrialDesignFisher(design)) {
-                conditionalCriticalValue[k] <- .getOneMinusQNorm(min((design$criticalValues[k + 1] /
-                    prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]), 1 - 1e-07))
+                conditionalCriticalValue[k] <- .getOneMinusQNorm(min(
+                    (criticalValues[k + 1] /
+                        prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]),
+                    1 - 1e-07
+                ))
             } else {
-                conditionalCriticalValue[k] <- (design$criticalValues[k + 1] *
+                conditionalCriticalValue[k] <- (criticalValues[k + 1] *
                     sqrt(design$informationRates[k + 1]) -
                     .getOneMinusQNorm(adjustedPValues[1:k]) %*% weights[1:k]) /
                     sqrt(design$informationRates[k + 1] - design$informationRates[k])
@@ -316,11 +383,18 @@ NULL
                     maxNumberOfSubjectsPerStage = maxNumberOfSubjectsPerStage
                 )
 
-                if (is.null(newSubjects) || length(newSubjects) != 1 ||
-                        !is.numeric(newSubjects) || is.na(newSubjects) || newSubjects < 0) {
+                if (
+                    is.null(newSubjects) ||
+                        length(newSubjects) != 1 ||
+                        !is.numeric(newSubjects) ||
+                        is.na(newSubjects) ||
+                        newSubjects < 0
+                ) {
                     stop(
                         C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
-                        "'calcSubjectsFunction' returned an illegal or undefined result (", newSubjects, "); ",
+                        "'calcSubjectsFunction' returned an illegal or undefined result (",
+                        newSubjects,
+                        "); ",
                         "the output must be a single numeric value >= 0"
                     )
                 }
@@ -337,9 +411,14 @@ NULL
                 thetaStandardized <- thetaH1 / stDevH1
             }
 
-            conditionalPowerPerStage[k] <- 1 - stats::pnorm(conditionalCriticalValue[k] -
-                thetaStandardized * sqrt(plannedSubjects[k + 1] - plannedSubjects[k]) *
-                    sqrt(allocationRatioPlanned[k]) / (1 + allocationRatioPlanned[k]))
+            conditionalPowerPerStage[k] <- 1 -
+                stats::pnorm(
+                    conditionalCriticalValue[k] -
+                        thetaStandardized *
+                            sqrt(plannedSubjects[k + 1] - plannedSubjects[k]) *
+                            sqrt(allocationRatioPlanned[k]) /
+                            (1 + allocationRatioPlanned[k])
+                )
         }
     }
 
@@ -425,37 +504,44 @@ NULL
 #'
 #' @export
 #'
-getSimulationEnrichmentMeans <- function(design = NULL, ...,
-        effectList = NULL,
-        intersectionTest = c("Simes", "SpiessensDebois", "Bonferroni", "Sidak"), # C_INTERSECTION_TEST_ENRICHMENT_DEFAULT
-        stratifiedAnalysis = TRUE, # C_STRATIFIED_ANALYSIS_DEFAULT,
-        adaptations = NA,
-        typeOfSelection = c("best", "rBest", "epsilon", "all", "userDefined"), # C_TYPE_OF_SELECTION_DEFAULT
-        effectMeasure = c("effectEstimate", "testStatistic"), # C_EFFECT_MEASURE_DEFAULT
-        successCriterion = c("all", "atLeastOne"), # C_SUCCESS_CRITERION_DEFAULT
-        epsilonValue = NA_real_,
-        rValue = NA_real_,
-        threshold = -Inf,
-        plannedSubjects = NA_integer_,
-        allocationRatioPlanned = NA_real_,
-        minNumberOfSubjectsPerStage = NA_real_,
-        maxNumberOfSubjectsPerStage = NA_real_,
-        conditionalPower = NA_real_,
-        thetaH1 = NA_real_,
-        stDevH1 = NA_real_,
-        maxNumberOfIterations = 1000L, # C_MAX_SIMULATION_ITERATIONS_DEFAULT
-        seed = NA_real_,
-        calcSubjectsFunction = NULL,
-        selectPopulationsFunction = NULL,
-        showStatistics = FALSE) {
+getSimulationEnrichmentMeans <- function(
+    design = NULL,
+    ...,
+    effectList = NULL,
+    intersectionTest = c("Simes", "SpiessensDebois", "Bonferroni", "Sidak"), # C_INTERSECTION_TEST_ENRICHMENT_DEFAULT
+    stratifiedAnalysis = TRUE, # C_STRATIFIED_ANALYSIS_DEFAULT,
+    adaptations = NA,
+    typeOfSelection = c("best", "rBest", "epsilon", "all", "userDefined"), # C_TYPE_OF_SELECTION_DEFAULT
+    effectMeasure = c("effectEstimate", "testStatistic"), # C_EFFECT_MEASURE_DEFAULT
+    successCriterion = c("all", "atLeastOne"), # C_SUCCESS_CRITERION_DEFAULT
+    epsilonValue = NA_real_,
+    rValue = NA_real_,
+    threshold = -Inf,
+    plannedSubjects = NA_integer_,
+    allocationRatioPlanned = NA_real_,
+    minNumberOfSubjectsPerStage = NA_real_,
+    maxNumberOfSubjectsPerStage = NA_real_,
+    conditionalPower = NA_real_,
+    thetaH1 = NA_real_,
+    stDevH1 = NA_real_,
+    maxNumberOfIterations = 1000L, # C_MAX_SIMULATION_ITERATIONS_DEFAULT
+    seed = NA_real_,
+    calcSubjectsFunction = NULL,
+    selectPopulationsFunction = NULL,
+    showStatistics = FALSE
+) {
     if (is.null(design)) {
         design <- .getDefaultDesign(..., type = "simulation")
         .warnInCaseOfUnknownArguments(
             functionName = "getSimulationEnrichmentMeans",
-            ignore = c(.getDesignArgumentsToIgnoreAtUnknownArgumentCheck(
-                design,
-                powerCalculationEnabled = TRUE
-            ), "showStatistics"), ...
+            ignore = c(
+                .getDesignArgumentsToIgnoreAtUnknownArgumentCheck(
+                    design,
+                    powerCalculationEnabled = TRUE
+                ),
+                "showStatistics"
+            ),
+            ...
         )
     } else {
         .assertIsTrialDesignInverseNormalOrFisher(design)
@@ -468,30 +554,30 @@ getSimulationEnrichmentMeans <- function(design = NULL, ...,
     calcSubjectsFunctionIsUserDefined <- !is.null(calcSubjectsFunction)
 
     simulationResults <- .createSimulationResultsEnrichmentObject(
-        design                      = design,
-        effectList                  = effectList,
-        intersectionTest            = intersectionTest,
-        stratifiedAnalysis          = stratifiedAnalysis,
-        adaptations                 = adaptations,
-        typeOfSelection             = typeOfSelection,
-        effectMeasure               = effectMeasure,
-        successCriterion            = successCriterion,
-        epsilonValue                = epsilonValue,
-        rValue                      = rValue,
-        threshold                   = threshold,
-        plannedSubjects             = plannedSubjects, # means + rates only
-        allocationRatioPlanned      = allocationRatioPlanned,
+        design = design,
+        effectList = effectList,
+        intersectionTest = intersectionTest,
+        stratifiedAnalysis = stratifiedAnalysis,
+        adaptations = adaptations,
+        typeOfSelection = typeOfSelection,
+        effectMeasure = effectMeasure,
+        successCriterion = successCriterion,
+        epsilonValue = epsilonValue,
+        rValue = rValue,
+        threshold = threshold,
+        plannedSubjects = plannedSubjects, # means + rates only
+        allocationRatioPlanned = allocationRatioPlanned,
         minNumberOfSubjectsPerStage = minNumberOfSubjectsPerStage, # means + rates only
         maxNumberOfSubjectsPerStage = maxNumberOfSubjectsPerStage, # means + rates only
-        conditionalPower            = conditionalPower,
-        thetaH1                     = thetaH1, # means + survival only
-        stDevH1                     = stDevH1, # means only
-        maxNumberOfIterations       = maxNumberOfIterations,
-        seed                        = seed,
-        calcSubjectsFunction        = calcSubjectsFunction, # means + rates only
-        selectPopulationsFunction   = selectPopulationsFunction,
-        showStatistics              = showStatistics,
-        endpoint                    = "means"
+        conditionalPower = conditionalPower,
+        thetaH1 = thetaH1, # means + survival only
+        stDevH1 = stDevH1, # means only
+        maxNumberOfIterations = maxNumberOfIterations,
+        seed = seed,
+        calcSubjectsFunction = calcSubjectsFunction, # means + rates only
+        selectPopulationsFunction = selectPopulationsFunction,
+        showStatistics = showStatistics,
+        endpoint = "means"
     )
 
     design <- simulationResults$.design
@@ -537,9 +623,6 @@ getSimulationEnrichmentMeans <- function(design = NULL, ...,
     dataPopulationNumber <- rep(NA_real_, len)
     dataEffect <- rep(NA_real_, len)
     dataSubjectsPopulation <- rep(NA_real_, len)
-    dataSubjectsActivePopulation <- rep(NA_real_, len)
-    dataNumberOfSubjects <- rep(NA_real_, len)
-    dataNumberOfCumulatedSubjects <- rep(NA_real_, len)
     dataRejectPerStage <- rep(NA, len)
     dataFutilityStop <- rep(NA_real_, len)
     dataSuccessStop <- rep(NA, len)
@@ -560,8 +643,8 @@ getSimulationEnrichmentMeans <- function(design = NULL, ...,
     }
 
     index <- 1
-    for (i in 1:cols) {
-        for (j in 1:maxNumberOfIterations) {
+    for (i in seq_len(cols)) {
+        for (j in seq_len(maxNumberOfIterations)) {
             stageResults <- .getSimulatedStageMeansEnrichment(
                 design = design,
                 subsets = effectList$subsets,
@@ -589,14 +672,16 @@ getSimulationEnrichmentMeans <- function(design = NULL, ...,
 
             closedTest <- .performClosedCombinationTestForSimulationEnrichment(
                 stageResults = stageResults,
-                design = design, indices = indices,
-                intersectionTest = intersectionTest, successCriterion = successCriterion
+                design = design,
+                indices = indices,
+                intersectionTest = intersectionTest,
+                successCriterion = successCriterion
             )
 
             rejectAtSomeStage <- FALSE
             rejectedPopulationsBefore <- rep(FALSE, gMax)
 
-            for (k in 1:kMax) {
+            for (k in seq_len(kMax)) {
                 simulatedRejections[k, i, ] <- simulatedRejections[k, i, ] +
                     (closedTest$rejected[, k] & closedTest$selectedPopulations[1:gMax, k] | rejectedPopulationsBefore)
                 simulatedSelections[k, i, ] <- simulatedSelections[k, i, ] + closedTest$selectedPopulations[, k]
@@ -608,7 +693,7 @@ getSimulationEnrichmentMeans <- function(design = NULL, ...,
                     simulatedSuccessStopping[k, i] <- simulatedSuccessStopping[k, i] + closedTest$successStop[k]
                 }
 
-                if ((kMax > 1) && (k < kMax)) {
+                if (kMax > 1 && k < kMax) {
                     if (!any(is.na(closedTest$futilityStop))) {
                         simulatedFutilityStopping[k, i] <- simulatedFutilityStopping[k, i] +
                             (closedTest$futilityStop[k] && !closedTest$successStop[k])
@@ -621,25 +706,19 @@ getSimulationEnrichmentMeans <- function(design = NULL, ...,
 
                 iterations[k, i] <- iterations[k, i] + 1
 
-                for (p in 1:2^(gMax - 1)) {
+                for (p in seq_len(2^(gMax - 1))) {
                     if (!is.na(stageResults$subjectsPerStage[p, k])) {
                         simulatedSubjectsPerStage[k, i, p] <- simulatedSubjectsPerStage[k, i, p] +
                             stageResults$subjectsPerStage[p, k]
                     }
                 }
 
-                for (g in 1:gMax) {
+                for (g in seq_len(gMax)) {
                     dataIterationNumber[index] <- j
                     dataStageNumber[index] <- k
                     dataPopulationNumber[index] <- g
                     dataEffect[index] <- i
                     dataSubjectsPopulation[index] <- round(stageResults$populationSubjectsPerStage[g, k], 1)
-                    dataSubjectsActivePopulation[index] <- round(stageResults$populationSubjectsPerStage[g, k], 1)
-                    dataNumberOfSubjects[index] <- round(sum(stageResults$populationSubjectsPerStage[, k], na.rm = TRUE), 1)
-                    dataNumberOfCumulatedSubjects[index] <- round(sum(
-                        stageResults$populationSubjectsPerStage[, 1:k],
-                        na.rm = TRUE
-                    ), 1)
                     dataRejectPerStage[index] <- closedTest$rejected[g, k]
                     dataTestStatistics[index] <- stageResults$testStatistics[g, k]
                     dataSuccessStop[index] <- closedTest$successStop[k]
@@ -653,26 +732,35 @@ getSimulationEnrichmentMeans <- function(design = NULL, ...,
                     index <- index + 1
                 }
 
-                if (!rejectAtSomeStage && any(closedTest$rejected[, k] &
-                        closedTest$selectedPopulations[1:gMax, k] | rejectedPopulationsBefore)) {
+                if (
+                    !rejectAtSomeStage &&
+                        any(
+                            closedTest$rejected[, k] &
+                                closedTest$selectedPopulations[1:gMax, k] |
+                                rejectedPopulationsBefore
+                        )
+                ) {
                     simulatedRejectAtLeastOne[i] <- simulatedRejectAtLeastOne[i] + 1
                     rejectAtSomeStage <- TRUE
                 }
 
-                if ((k < kMax) && (closedTest$successStop[k] || closedTest$futilityStop[k])) {
+                if (k < kMax && (closedTest$successStop[k] || closedTest$futilityStop[k])) {
                     # rejected hypotheses remain rejected also in case of early stopping
                     simulatedRejections[(k + 1):kMax, i, ] <- simulatedRejections[(k + 1):kMax, i, ] +
                         matrix(
                             (closedTest$rejected[, k] &
-                                closedTest$selectedPopulations[1:gMax, k] | rejectedPopulationsBefore),
-                            kMax - k, gMax,
+                                closedTest$selectedPopulations[1:gMax, k] |
+                                rejectedPopulationsBefore),
+                            kMax - k,
+                            gMax,
                             byrow = TRUE
                         )
                     break
                 }
 
                 rejectedPopulationsBefore <- closedTest$rejected[, k] &
-                    closedTest$selectedPopulations[1:gMax, k] | rejectedPopulationsBefore
+                    closedTest$selectedPopulations[1:gMax, k] |
+                    rejectedPopulationsBefore
             }
         }
 
@@ -681,10 +769,15 @@ getSimulationEnrichmentMeans <- function(design = NULL, ...,
         simulatedSubjectsPerStage[, i, ] <- simulatedSubjectsPerStage[, i, ] / iterations[, i]
 
         if (kMax > 1) {
-            simulatedRejections[2:kMax, i, ] <- simulatedRejections[2:kMax, i, ] - simulatedRejections[1:(kMax - 1), i, ]
-            stopping <- cumsum(simulatedSuccessStopping[1:(kMax - 1), i] + simulatedFutilityStopping[, i]) / maxNumberOfIterations
-            expectedNumberOfSubjects[i] <- sum(simulatedSubjectsPerStage[1, i, ] + t(1 - stopping) %*%
-                simulatedSubjectsPerStage[2:kMax, i, ])
+            simulatedRejections[2:kMax, i, ] <- simulatedRejections[2:kMax, i, ] -
+                simulatedRejections[1:(kMax - 1), i, ]
+            stopping <- cumsum(simulatedSuccessStopping[1:(kMax - 1), i] + simulatedFutilityStopping[, i]) /
+                maxNumberOfIterations
+            expectedNumberOfSubjects[i] <- sum(
+                simulatedSubjectsPerStage[1, i, ] +
+                    t(1 - stopping) %*%
+                        simulatedSubjectsPerStage[2:kMax, i, ]
+            )
         } else {
             expectedNumberOfSubjects[i] <- sum(simulatedSubjectsPerStage[1, i, ])
         }
@@ -724,8 +817,6 @@ getSimulationEnrichmentMeans <- function(design = NULL, ...,
         stageNumber = dataStageNumber,
         populationNumber = dataPopulationNumber,
         effect = dataEffect,
-        numberOfSubjects = dataNumberOfSubjects,
-        numberOfCumulatedSubjects = dataNumberOfCumulatedSubjects,
         subjectsPopulation = dataSubjectsPopulation,
         effectEstimate = dataEffectEstimate,
         testStatistic = dataTestStatistics,
