@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 7910 $
-## |  Last changed: $Date: 2024-05-22 10:02:23 +0200 (Mi, 22 Mai 2024) $
+## |  File version: $Revision: 8731 $
+## |  Last changed: $Date: 2025-05-23 12:09:53 +0200 (Fr, 23 Mai 2025) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -46,11 +46,10 @@ NULL
                 piAssumedControlH1 <- piControlH1
             }
             if (is.na(piTreatmentsH1)) {
-                if (directionUpper) {
-                    piAssumedH1 <- min(overallRates[selectedArms[1:gMax, stage + 1], stage], na.rm = TRUE)
-                } else {
-                    piAssumedH1 <- max(overallRates[selectedArms[1:gMax, stage + 1], stage], na.rm = TRUE)
-                }
+                piAssumedH1 <- .applyDirectionOfAlternative(
+                    overallRates[selectedArms[1:gMax, stage + 1], stage], 
+                    directionUpper, type = "minMax", phase = "planning"
+                )
             } else {
                 piAssumedH1 <- piTreatmentsH1
             }
@@ -105,7 +104,7 @@ NULL
         weights <- .getWeightsInverseNormal(design)
     }
 
-    for (k in (1:kMax)) {
+    for (k in 1:kMax) {
         if (k == 1) {
             subjectsPerStage[gMax + 1, k] <- trunc(plannedSubjects[k] / allocationRatioPlanned[k])
         } else {
@@ -175,14 +174,15 @@ NULL
                     .getOneMinusQNorm(adjustedPValues[k]) * sqrt(design$informationAtInterim)) /
                     sqrt(1 - design$informationAtInterim)
             } else {
+                criticalValues <- .getCriticalValues(design)
                 if (.isTrialDesignFisher(design)) {
-                    conditionalCriticalValue[k] <- .getOneMinusQNorm(min((design$criticalValues[k + 1] /
+                    conditionalCriticalValue[k] <- .getOneMinusQNorm(min((criticalValues[k + 1] /
                         prod(adjustedPValues[1:k]^weights[1:k]))^(1 / weights[k + 1]), 1 - 1e-07))
                 } else {
-                    if (design$criticalValues[k + 1] >= 6) {
+                    if (criticalValues[k + 1] >= 6) {
                         conditionalCriticalValue[k] <- Inf
                     } else {
-                        conditionalCriticalValue[k] <- (design$criticalValues[k + 1] * sqrt(design$informationRates[k + 1]) -
+                        conditionalCriticalValue[k] <- (criticalValues[k + 1] * sqrt(design$informationRates[k + 1]) -
                             .getOneMinusQNorm(adjustedPValues[1:k]) %*% weights[1:k]) /
                             sqrt(design$informationRates[k + 1] - design$informationRates[k])
                     }
@@ -262,11 +262,10 @@ NULL
             }
 
             if (is.na(piTreatmentsH1)) {
-                if (directionUpper) {
-                    piAssumedH1 <- min(overallRates[selectedArms[1:gMax, k], k], na.rm = TRUE)
-                } else {
-                    piAssumedH1 <- max(overallRates[selectedArms[1:gMax, k], k], na.rm = TRUE)
-                }
+                piAssumedH1 <- .applyDirectionOfAlternative(
+                    overallRates[selectedArms[1:gMax, k], k], 
+                    directionUpper, type = "minMax", phase = "planning"
+                )
             } else {
                 piAssumedH1 <- piTreatmentsH1
             }
@@ -336,7 +335,7 @@ NULL
 #' @inheritParams param_effectMatrix
 #' @inheritParams param_activeArms
 #' @inheritParams param_successCriterion
-#' @inheritParams param_typeOfShape
+#' @inheritParams param_typeOfShapeRates
 #' @inheritParams param_typeOfSelection
 #' @inheritParams param_design_with_default
 #' @inheritParams param_directionUpper
@@ -352,6 +351,7 @@ NULL
 #' @inheritParams param_epsilonValue
 #' @inheritParams param_gED50
 #' @inheritParams param_slope
+#' @inheritParams param_doseLevels
 #' @inheritParams param_seed
 #' @inheritParams param_three_dots
 #' @inheritParams param_showStatistics
@@ -394,15 +394,16 @@ NULL
 #' @export
 #'
 getSimulationMultiArmRates <- function(design = NULL, ...,
-        activeArms = 3L, # C_ACTIVE_ARMS_DEFAULT
+        activeArms = NA_integer_, # C_ACTIVE_ARMS_DEFAULT = 3L
         effectMatrix = NULL,
         typeOfShape = c("linear", "sigmoidEmax", "userDefined"), # C_TYPE_OF_SHAPE_DEFAULT
         piMaxVector = seq(0.2, 0.5, 0.1), # C_PI_1_DEFAULT
         piControl = 0.2, # C_PI_2_DEFAULT
         gED50 = NA_real_,
         slope = 1,
+        doseLevels = NA_real_,
         intersectionTest = c("Dunnett", "Bonferroni", "Simes", "Sidak", "Hierarchical"), # C_INTERSECTION_TEST_MULTIARMED_DEFAULT
-        directionUpper = TRUE, # C_DIRECTION_UPPER_DEFAULT
+        directionUpper = NA, # C_DIRECTION_UPPER_DEFAULT
         adaptations = NA,
         typeOfSelection = c("best", "rBest", "epsilon", "all", "userDefined"), # C_TYPE_OF_SELECTION_DEFAULT
         effectMeasure = c("effectEstimate", "testStatistic"), # C_EFFECT_MEASURE_DEFAULT
@@ -444,6 +445,9 @@ getSimulationMultiArmRates <- function(design = NULL, ...,
 
     calcSubjectsFunctionIsUserDefined <- !is.null(calcSubjectsFunction)
 
+    directionUpper <- .assertIsValidDirectionUpper(directionUpper, 
+        design, objectType = "power", userFunctionCallEnabled = TRUE)
+    
     simulationResults <- .createSimulationResultsMultiArmObject(
         design                      = design,
         activeArms                  = activeArms,
@@ -453,6 +457,7 @@ getSimulationMultiArmRates <- function(design = NULL, ...,
         piControl                   = piControl, # rates only
         gED50                       = gED50,
         slope                       = slope,
+        doseLevels                  = doseLevels,
         intersectionTest            = intersectionTest,
         directionUpper              = directionUpper, # rates + survival only
         adaptations                 = adaptations,
@@ -481,7 +486,7 @@ getSimulationMultiArmRates <- function(design = NULL, ...,
     successCriterion <- simulationResults$successCriterion
     effectMeasure <- simulationResults$effectMeasure
     adaptations <- simulationResults$adaptations
-    gMax <- activeArms
+    gMax <- simulationResults$activeArms
     kMax <- simulationResults$.design$kMax
     intersectionTest <- simulationResults$intersectionTest
     typeOfSelection <- simulationResults$typeOfSelection
