@@ -13,8 +13,8 @@
 ## |
 ## |  Contact us for information about our services: info@rpact.com
 ## |
-## |  File version: $Revision: 8225 $
-## |  Last changed: $Date: 2024-09-18 09:38:40 +0200 (Mi, 18 Sep 2024) $
+## |  File version: $Revision: 8730 $
+## |  Last changed: $Date: 2025-05-23 12:07:33 +0200 (Fr, 23 Mai 2025) $
 ## |  Last changed by: $Author: pahlke $
 ## |
 
@@ -333,7 +333,7 @@ NULL
 #'        if \code{correlationComputation = "null"}, a constant correlation matrix valid
 #'        under the null, i.e., not accounting for the alternative is used,
 #'         default is \code{"alternative"}.
-#' @inheritParams param_typeOfShape
+#' @inheritParams param_typeOfShapeSurvival
 #' @inheritParams param_typeOfSelection
 #' @inheritParams param_design_with_default
 #' @inheritParams param_directionUpper
@@ -350,6 +350,7 @@ NULL
 #' @inheritParams param_epsilonValue
 #' @inheritParams param_gED50
 #' @inheritParams param_slope
+#' @inheritParams param_doseLevels
 #' @inheritParams param_seed
 #' @inheritParams param_three_dots
 #' @inheritParams param_showStatistics
@@ -388,13 +389,15 @@ NULL
 #'
 #' @export
 #'
-getSimulationMultiArmSurvival <- function(design = NULL, ...,
-        activeArms = 3L, # C_ACTIVE_ARMS_DEFAULT
+getSimulationMultiArmSurvival <- function(design = NULL,
+        ...,
+        activeArms = NA_integer_, # C_ACTIVE_ARMS_DEFAULT = 3L
         effectMatrix = NULL,
         typeOfShape = c("linear", "sigmoidEmax", "userDefined"), # C_TYPE_OF_SHAPE_DEFAULT
         omegaMaxVector = seq(1, 2.6, 0.4), # C_RANGE_OF_HAZARD_RATIOS_DEFAULT
         gED50 = NA_real_,
         slope = 1,
+        doseLevels = NA_real_,
         intersectionTest = c("Dunnett", "Bonferroni", "Simes", "Sidak", "Hierarchical"), # C_INTERSECTION_TEST_MULTIARMED_DEFAULT
         directionUpper = NA, # C_DIRECTION_UPPER_DEFAULT
         adaptations = NA,
@@ -436,9 +439,11 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
 
     calcEventsFunctionIsUserDefined <- !is.null(calcEventsFunction)
 
-    directionUpper <- .assertIsValidDirectionUpper(directionUpper, 
-        design, objectType = "power", userFunctionCallEnabled = TRUE)
-    
+    directionUpper <- .assertIsValidDirectionUpper(directionUpper,
+        design,
+        objectType = "power", userFunctionCallEnabled = TRUE
+    )
+
     simulationResults <- .createSimulationResultsMultiArmObject(
         design                      = design,
         activeArms                  = activeArms,
@@ -447,6 +452,7 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
         omegaMaxVector              = omegaMaxVector, # survival only
         gED50                       = gED50,
         slope                       = slope,
+        doseLevels                  = doseLevels,
         intersectionTest            = intersectionTest,
         directionUpper              = directionUpper, # rates + survival only
         adaptations                 = adaptations,
@@ -469,12 +475,24 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
         showStatistics              = showStatistics,
         endpoint                    = "survival"
     )
+    for (notApplicableParam in c(
+            "accrualIntensity",
+            "accrualTime",
+            "dropoutRate1",
+            "dropoutRate2",
+            "dropoutTime",
+            "eventTime",
+            "kappa",
+            "piControl")
+            ) {
+        simulationResults$.setParameterType(notApplicableParam, C_PARAM_NOT_APPLICABLE)
+    }
 
     design <- simulationResults$.design
     successCriterion <- simulationResults$successCriterion
     effectMeasure <- simulationResults$effectMeasure
     adaptations <- simulationResults$adaptations
-    gMax <- activeArms
+    gMax <- simulationResults$activeArms
     kMax <- simulationResults$.design$kMax
     intersectionTest <- simulationResults$intersectionTest
     typeOfSelection <- simulationResults$typeOfSelection
@@ -543,7 +561,7 @@ getSimulationMultiArmSurvival <- function(design = NULL, ...,
 
     if (correlationComputation == "null") {
         # not accounting for alternative
-        corrMatrix <- matrix(rep(allocationRatioPlanned / (1 + allocationRatioPlanned), gMax^2), ncol = gMax, nrow = gMax)
+        corrMatrix <- matrix(rep(allocationRatioPlanned[1] / (1 + allocationRatioPlanned[1]), gMax^2), ncol = gMax, nrow = gMax)
         diag(corrMatrix) <- 1
         choleskyDecomposition <- chol(corrMatrix)
     }
